@@ -51,11 +51,11 @@ namespace ac3 {
 
 class frame_c {
 public:
-  unsigned int m_sample_rate{}, m_bit_rate{}, m_channels{}, m_flags{}, m_bytes{}, m_bs_id{}, m_samples{}, m_frame_type{}, m_sub_stream_id{};
+  unsigned int m_sample_rate{}, m_bit_rate{}, m_channels{}, m_channel_layout{}, m_flags{}, m_bytes{}, m_bs_id{}, m_samples{}, m_frame_type{}, m_sub_stream_id{};
   unsigned int m_dialog_normalization_gain{}, m_dialog_normalization_gain_bit_position{};
   boost::optional<unsigned int> m_dialog_normalization_gain2, m_dialog_normalization_gain2_bit_position;
   uint64_t m_stream_position{}, m_garbage_size{};
-  bool m_valid{};
+  bool m_valid{}, m_lfeon{};
   memory_cptr m_data;
   std::vector<frame_c> m_dependent_frames;
 
@@ -68,6 +68,9 @@ public:
   bool decode_header_type_eac3(mtx::bits::reader_c &bc);
   bool decode_header_type_ac3(mtx::bits::reader_c &bc);
 
+  uint64_t get_effective_channel_layout() const;
+  int get_effective_number_of_channels() const;
+
   std::string to_string(bool verbose) const;
 
   int find_in(memory_cptr const &buffer);
@@ -97,7 +100,7 @@ public:
   void parse(bool end_of_stream);
 };
 
-bool verify_checksum1(unsigned char const *buf, std::size_t size);
+bool verify_checksums(unsigned char const *buf, std::size_t size, bool full_buffer = false);
 void remove_dialog_normalization_gain(unsigned char *buf, std::size_t size);
 
 }}                              // namespace mtx::ac3
