@@ -41,13 +41,26 @@ public:
   {
   }
 
+  writer_c(memory_c &data)
+    : m_data{data.get_buffer()}
+    , m_size{data.get_size()}
+    , m_data_size{data.get_size()}
+  {
+  }
+
   inline memory_cptr get_buffer() {
     return memory_c::clone(m_data, m_size);
   }
 
   inline uint64_t copy_bits(std::size_t n, reader_c &src) {
-    uint64_t value = src.get_bits(n);
-    put_bits(n, value);
+    uint64_t value{};
+
+    while (n) {
+      auto to_copy = std::min<std::size_t>(n, 64);
+      n           -= to_copy;
+      value        = src.get_bits(to_copy);
+      put_bits(to_copy, value);
+    }
 
     return value;
   }
@@ -56,11 +69,11 @@ public:
     int n = 0;
 
     while (r.get_bit() == 0) {
-      put_bit(0);
+      put_bit(false);
       ++n;
     }
 
-    put_bit(1);
+    put_bit(true);
 
     auto bits = copy_bits(n, r);
 
@@ -74,7 +87,7 @@ public:
 
   inline void put_bits(std::size_t n, uint64_t value) {
     while (0 < n) {
-      put_bit(value & (1ull << (n - 1)));
+      put_bit((value & (1ull << (n - 1))) != 0);
       --n;
     }
   }
@@ -99,7 +112,7 @@ public:
 
   inline void byte_align() {
     while (0x80 != m_mask)
-      put_bit(0);
+      put_bit(false);
   }
 
   inline void set_bit_position(std::size_t pos) {
