@@ -25,8 +25,7 @@ class value_parser_x: public exception {
 protected:
   std::string m_message;
 public:
-  value_parser_x(const std::string &message)  : m_message(message)       { }
-  value_parser_x(const boost::format &message): m_message(message.str()) { }
+  value_parser_x(const std::string &message) : m_message{message} { }
   virtual ~value_parser_x() throw() { }
 
   virtual const char *what() const throw() {
