@@ -44,9 +44,6 @@ crc_base_c::crc_base_c(type_e type,
     init_table();
 }
 
-crc_base_c::~crc_base_c() {
-}
-
 #ifdef COMP_MSC
 #pragma warning(disable:4146)	//unary minus operator applied to unsigned type, result still unsigned
 #endif
@@ -76,8 +73,7 @@ crc_base_c::init_table() {
   }
 
   // for (auto row = 0u; row < (256u / 4); ++row)
-  //   mxinfo(boost::format("0x%|1$08x| 0x%|2$08x| 0x%|3$08x| 0x%|4$08x|\n")
-  //          % m_table[row * 4 + 0] % m_table[row * 4 + 1] % m_table[row * 4 + 2] % m_table[row * 4 + 3]);
+  //   mxinfo(fmt::format("0x{0:08x} 0x{1:08x} 0x{2:08x} 0x{3:08x}\n", m_table[row * 4 + 0], m_table[row * 4 + 1], m_table[row * 4 + 2], m_table[row * 4 + 3]));
 }
 
 memory_cptr
@@ -145,9 +141,6 @@ crc8_atm_c::crc8_atm_c(uint32_t initial_value)
 {
 }
 
-crc8_atm_c::~crc8_atm_c() {
-}
-
 // ----------------------------------------------------------------------
 
 crc_base_c::table_t crc16_ansi_c::ms_table;
@@ -157,9 +150,6 @@ crc16_ansi_c::crc16_ansi_c(uint32_t initial_value)
 {
 }
 
-crc16_ansi_c::~crc16_ansi_c() {
-}
-
 // ----------------------------------------------------------------------
 
 crc_base_c::table_t crc16_ccitt_c::ms_table;
@@ -169,9 +159,6 @@ crc16_ccitt_c::crc16_ccitt_c(uint32_t initial_value)
 {
 }
 
-crc16_ccitt_c::~crc16_ccitt_c() {
-}
-
 // ----------------------------------------------------------------------
 
 crc_base_c::table_t crc16_002d_c::ms_table;
@@ -181,9 +168,6 @@ crc16_002d_c::crc16_002d_c(uint32_t initial_value)
 {
 }
 
-crc16_002d_c::~crc16_002d_c() {
-}
-
 // ----------------------------------------------------------------------
 
 crc_base_c::table_t crc32_ieee_c::ms_table;
@@ -193,9 +177,6 @@ crc32_ieee_c::crc32_ieee_c(uint32_t initial_value)
 {
 }
 
-crc32_ieee_c::~crc32_ieee_c() {
-}
-
 // ----------------------------------------------------------------------
 
 crc_base_c::table_t crc32_ieee_le_c::ms_table;
@@ -205,7 +186,4 @@ crc32_ieee_le_c::crc32_ieee_le_c(uint32_t initial_value)
 {
 }
 
-crc32_ieee_le_c::~crc32_ieee_le_c() {
-}
-
 }} // namespace mtx { namespace checksum {
