@@ -11,8 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_COMMON_ISO639_H
-#define MTX_COMMON_ISO639_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -20,7 +19,8 @@ struct iso639_language_t {
   std::string const english_name, iso639_2_code, iso639_1_code, terminology_abbrev;
 };
 
-extern std::vector<iso639_language_t> const iso639_languages;
+extern std::vector<iso639_language_t> const g_iso639_languages;
+extern std::vector<std::string> const g_popular_language_codes;
 
 int map_to_iso639_2_code(std::string const &s, bool allow_short_english_names = false);
 bool is_valid_iso639_2_code(std::string const &s);
@@ -28,5 +28,3 @@ std::string const &map_iso639_2_to_iso639_1(std::string const &iso639_2_code);
 void list_iso639_languages();
 bool is_popular_language(std::string const &lang);
 bool is_popular_language_code(std::string const &code);
-
-#endif // MTX_COMMON_ISO639_H
