@@ -114,7 +114,6 @@ protected:
   void init_custom_element_value_formatters_and_processors();
 
   void show_element(libebml::EbmlElement *l, int level, std::string const &info, boost::optional<int64_t> position = {}, boost::optional<int64_t> size = {});
-  void show_element(libebml::EbmlElement *l, int level, boost::format const &info, boost::optional<int64_t> position = {}, boost::optional<int64_t> size = {});
 
   void add_track(std::shared_ptr<kax_info::track_t> const &t);
   kax_info::track_t *find_track(int tnum);
@@ -130,8 +129,6 @@ protected:
   void retain_element(std::shared_ptr<libebml::EbmlElement> const &element);
 
 public:
-  static void init_common_formats();
-
   static std::string format_ebml_id_as_hex(libebml::EbmlElement &e);
   static std::string format_ebml_id_as_hex(libebml::EbmlId const &id);
   static std::string format_ebml_id_as_hex(uint32_t id);
