@@ -48,4 +48,20 @@ int_to_double(int64_t value) {
   return std::ldexp(((value & ((1ll << 52) - 1)) + (1ll << 52)) * (value >> 63 | 1), (value >> 52 & 0x7ff) - 1075);
 }
 
+int64_rational_c
+clamp_values_to(int64_rational_c const &r,
+                int64_t max_value) {
+  auto num = r.numerator();
+  auto den = r.denominator();
+
+  if (!num || !den || ((num <= max_value) && (den <= max_value)))
+    return r;
+
+  // 333 / 1000 , clamp = 500, mul = 1/2 = 1/(max/clamp) = clamp/max
+
+  auto mult = int64_rational_c{ max_value, std::max(num, den) };
+  den       = boost::rational_cast<int64_t>(den * mult);
+
+  return { boost::rational_cast<int64_t>(num * mult), den ? den : 1 };
+}
 }}
