@@ -11,16 +11,10 @@
    Written by Moritz Bunkus <moritz@bunkus.org>
 */
 
-#ifndef MTX_COMMON_SEGMENTINFO_H
-#define MTX_COMMON_SEGMENTINFO_H
+#pragma once
 
 #include "common/common_pch.h"
 
 #include <matroska/KaxInfo.h>
 
-using namespace libebml;
-using namespace libmatroska;
-
-using kax_info_cptr = std::shared_ptr<KaxInfo>;
-
-#endif // MTX_COMMON_SEGMENTINFO_H
+using kax_info_cptr = std::shared_ptr<libmatroska::KaxInfo>;
