@@ -10,8 +10,7 @@
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_COMMON_SPLIT_ARG_PARSING_H
-#define MTX_COMMON_SPLIT_ARG_PARSING_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -23,8 +22,7 @@ class format_x: public exception {
 protected:
   std::string m_message;
 public:
-  explicit format_x(std::string const &message)  : m_message(message)       { }
-  explicit format_x(boost::format const &message): m_message(message.str()) { }
+  explicit format_x(std::string const &message) : m_message{message} { }
   virtual ~format_x() throw() { }
 
   virtual char const *what() const throw() {
@@ -35,5 +33,3 @@ public:
 std::vector<split_point_c> parse_split_parts(const std::string &arg, bool frames_fields);
 
 }}
-
-#endif // MTX_COMMON_SPLIT_ARG_PARSING_H
