@@ -46,36 +46,27 @@ split(std::string const &text,
 void
 strip_back(std::string &s,
            bool newlines) {
-  const char *c = s.c_str();
-  int len       = s.length();
-  int i         = 0;
+  auto c  = s.c_str();
+  int idx = 0, len = s.length();
 
-  if (newlines)
-    while ((i < len) && (isblanktab(c[len - i - 1]) || iscr(c[len - i - 1])))
-      ++i;
-  else
-    while ((i < len) && isblanktab(c[len - i - 1]))
-      ++i;
+  while ((idx < len) && (!c[len - idx - 1] || isblanktab(c[len - idx - 1]) || (newlines && iscr(c[len - idx - 1]))))
+    ++idx;
 
-  if (i > 0)
-    s.erase(len - i, i);
+  if (idx > 0)
+    s.erase(len - idx, idx);
 }
 
 void
 strip(std::string &s,
       bool newlines) {
-  const char *c = s.c_str();
-  int i         = 0;
+  auto c  = s.c_str();
+  int idx = 0, len = s.length();
 
-  if (newlines)
-    while ((c[i] != 0) && (isblanktab(c[i]) || iscr(c[i])))
-      i++;
-  else
-    while ((c[i] != 0) && isblanktab(c[i]))
-      i++;
+  while ((idx < len) && (!c[idx] || isblanktab(c[idx]) || (newlines && iscr(c[idx]))))
+    ++idx;
 
-  if (i > 0)
-    s.erase(0, i);
+  if (idx > 0)
+    s.erase(0, idx);
 
   strip_back(s, newlines);
 }
@@ -118,70 +109,6 @@ shrink_whitespace(std::string &s) {
   return s;
 }
 
-std::string
-escape(const std::string &source) {
-  std::string dst;
-  std::string::const_iterator src;
-
-  for (src = source.begin(); src < source.end(); src++) {
-    if (*src == '\\')
-      dst += "\\\\";
-    else if (*src == '"')
-      dst += "\\2";               // Yes, this IS a trick ;)
-    else if (*src == ' ')
-      dst += "\\s";
-    else if (*src == ':')
-      dst += "\\c";
-    else if (*src == '#')
-      dst += "\\h";
-    else if (*src == '[')
-      dst += "\\b";
-    else if (*src == ']')
-      dst += "\\B";
-    else
-      dst += *src;
-  }
-
-  return dst;
-}
-
-std::string
-unescape(const std::string &source) {
-  std::string dst;
-  std::string::const_iterator src, next_char;
-
-  src = source.begin();
-  next_char = src + 1;
-  while (src != source.end()) {
-    if (*src == '\\') {
-      if (next_char == source.end()) // This is an error...
-        dst += '\\';
-      else {
-        if (*next_char == '2')
-          dst += '"';
-        else if (*next_char == 's')
-          dst += ' ';
-        else if (*next_char == 'c')
-          dst += ':';
-        else if (*next_char == 'h')
-          dst += '#';
-        else if (*next_char == 'b')
-          dst += '[';
-        else if (*next_char == 'B')
-          dst += ']';
-        else
-          dst += *next_char;
-        src++;
-      }
-    } else
-      dst += *src;
-    src++;
-    next_char = src + 1;
-  }
-
-  return dst;
-}
-
 std::string
 get_displayable_string(const char *src,
                        int max_len) {
