@@ -29,11 +29,6 @@ to_wide(std::wstring const &source) {
   return source;
 }
 
-inline std::wstring
-to_wide(boost::wformat const &source) {
-  return source.str();
-}
-
 inline std::wstring
 to_wide(::libebml::UTFstring const &source) {
   return source.c_str();
@@ -44,11 +39,6 @@ to_utfstring(std::wstring const &source) {
   return libebml::UTFstring{source};
 }
 
-inline ::libebml::UTFstring
-to_utfstring(boost::wformat const &source) {
-  return to_utfstring(source.str());
-}
-
 inline ::libebml::UTFstring
 to_utfstring(std::string const &source) {
   auto u = libebml::UTFstring{};
@@ -56,11 +46,6 @@ to_utfstring(std::string const &source) {
   return u;
 }
 
-inline ::libebml::UTFstring
-to_utfstring(boost::format const &source) {
-  return to_utfstring(source.str());
-}
-
 std::string to_utf8(const std::wstring &source);
 
 inline std::string
@@ -73,11 +58,6 @@ to_utf8(std::string const &source) {
   return source;
 }
 
-inline std::string
-to_utf8(boost::format const &source) {
-  return source.str();
-}
-
 inline std::string
 to_utf8(::libebml::UTFstring const &source) {
   return source.GetUTF8();
