@@ -31,53 +31,50 @@ namespace libebml {
   class EbmlMaster;
 };
 
-using namespace libebml;
-using namespace libmatroska;
-
 namespace mtx { namespace tags {
 
-void remove_track_uid_targets(EbmlMaster *tag);
-void remove_elements_unsupported_by_webm(EbmlMaster &master);
-bool remove_track_statistics(KaxTags *tags, boost::optional<uint64_t> track_uid);
+void remove_track_uid_targets(libebml::EbmlMaster *tag);
+void remove_elements_unsupported_by_webm(libebml::EbmlMaster &master);
+bool remove_track_statistics(libmatroska::KaxTags *tags, boost::optional<uint64_t> track_uid);
 
-KaxTags *select_for_chapters(KaxTags &tags, KaxChapters &chapters);
+libmatroska::KaxTags *select_for_chapters(libmatroska::KaxTags &tags, libmatroska::KaxChapters &chapters);
 
-KaxTagSimple &find_simple(const std::string &name, EbmlMaster &m);
-KaxTagSimple &find_simple(const UTFstring &name, EbmlMaster &m);
-std::string get_simple_value(const std::string &name, EbmlMaster &m);
-int64_t get_tuid(const KaxTag &tag);
-int64_t get_cuid(const KaxTag &tag);
+libmatroska::KaxTagSimple &find_simple(const std::string &name, libebml::EbmlMaster &m);
+libmatroska::KaxTagSimple &find_simple(const UTFstring &name, libebml::EbmlMaster &m);
+std::string get_simple_value(const std::string &name, libebml::EbmlMaster &m);
+int64_t get_tuid(const libmatroska::KaxTag &tag);
+int64_t get_cuid(const libmatroska::KaxTag &tag);
 
-std::string get_simple_name(const KaxTagSimple &tag);
-std::string get_simple_value(const KaxTagSimple &tag);
+std::string get_simple_name(const libmatroska::KaxTagSimple &tag);
+std::string get_simple_value(const libmatroska::KaxTagSimple &tag);
 
-void set_simple_name(KaxTagSimple &tag, const std::string &name);
-void set_simple_value(KaxTagSimple &tag, const std::string &value);
-void set_simple(KaxTagSimple &tag, const std::string &name, const std::string &value);
-void set_simple(KaxTag &tag, std::string const &name, std::string const &value, std::string const &language = "eng");
-void set_target_type(KaxTag &tag, target_type_e target_type_value, std::string const &target_type);
+void set_simple_name(libmatroska::KaxTagSimple &tag, const std::string &name);
+void set_simple_value(libmatroska::KaxTagSimple &tag, const std::string &value);
+void set_simple(libmatroska::KaxTagSimple &tag, const std::string &name, const std::string &value);
+void set_simple(libmatroska::KaxTag &tag, std::string const &name, std::string const &value, std::string const &language = "eng");
+void set_target_type(libmatroska::KaxTag &tag, target_type_e target_type_value, std::string const &target_type);
 
-int count_simple(EbmlMaster &master);
+int count_simple(libebml::EbmlMaster &master);
 
-void convert_old(KaxTags &tags);
+void convert_old(libmatroska::KaxTags &tags);
 
 template<typename T>
-KaxTag *
-find_tag_for(KaxTags &tags,
+libmatroska::KaxTag *
+find_tag_for(libmatroska::KaxTags &tags,
              uint64_t id,
              target_type_e target_type,
              bool create_if_not_found) {
   for (auto &element : tags) {
-    auto tag = dynamic_cast<KaxTag *>(element);
+    auto tag = dynamic_cast<libmatroska::KaxTag *>(element);
     if (!tag)
       continue;
 
-    auto targets = FindChild<KaxTagTargets>(*tag);
+    auto targets = FindChild<libmatroska::KaxTagTargets>(*tag);
     if (!targets)
       continue;
 
     if (Unknown != target_type) {
-      auto actual_target_type = static_cast<target_type_e>(FindChildValue<KaxTagTargetTypeValue>(*targets, 0ull));
+      auto actual_target_type = static_cast<target_type_e>(FindChildValue<libmatroska::KaxTagTargetTypeValue>(*targets, 0ull));
       if (actual_target_type != target_type)
         continue;
     }
@@ -90,11 +87,11 @@ find_tag_for(KaxTags &tags,
   if (!create_if_not_found)
     return nullptr;
 
-  auto tag = new KaxTag;
+  auto tag = new libmatroska::KaxTag;
   tags.PushElement(*tag);
 
-  auto &targets = GetChild<KaxTagTargets>(tag);
-  GetChild<KaxTagTargetTypeValue>(targets).SetValue(target_type);
+  auto &targets = GetChild<libmatroska::KaxTagTargets>(tag);
+  GetChild<libmatroska::KaxTagTargetTypeValue>(targets).SetValue(target_type);
   GetChild<T>(targets).SetValue(id);
 
   return tag;
@@ -102,20 +99,20 @@ find_tag_for(KaxTags &tags,
 
 template<typename T>
 bool
-remove_simple_tags_for(KaxTags &tags,
+remove_simple_tags_for(libmatroska::KaxTags &tags,
                        boost::optional<uint64_t> id,
                        std::string const &name_to_remove) {
   auto removed_something = false;
   auto tag_idx = 0u;
   while (tag_idx < tags.ListSize()) {
-    auto tag = dynamic_cast<KaxTag *>(tags[tag_idx]);
+    auto tag = dynamic_cast<libmatroska::KaxTag *>(tags[tag_idx]);
     if (!tag) {
       ++tag_idx;
       continue;
     }
 
     if (id) {
-      auto targets   = FindChild<KaxTagTargets>(*tag);
+      auto targets   = FindChild<libmatroska::KaxTagTargets>(*tag);
       auto actual_id = targets ? boost::optional<uint64_t>{ FindChildValue<T>(*targets, 0llu) } : boost::optional<uint64_t>{ boost::none };
 
       if (!targets || !actual_id || (*actual_id != *id)) {
@@ -126,7 +123,7 @@ remove_simple_tags_for(KaxTags &tags,
 
     auto simple_idx = 0u;
     while (simple_idx < tag->ListSize()) {
-      auto simple = dynamic_cast<KaxTagSimple *>((*tag)[simple_idx]);
+      auto simple = dynamic_cast<libmatroska::KaxTagSimple *>((*tag)[simple_idx]);
       if (!simple || (to_utf8(get_simple_name(*simple)) != name_to_remove))
         ++simple_idx;
 
