@@ -18,8 +18,6 @@
 #include "common/segmentinfo.h"
 #include "common/xml/ebml_converter.h"
 
-using namespace libmatroska;
-
 namespace mtx { namespace xml {
 
 class ebml_segmentinfo_converter_c: public ebml_converter_c {
@@ -31,7 +29,7 @@ protected:
   void setup_maps();
 
 public:
-  static void write_xml(KaxInfo &segmentinfo, mm_io_c &out);
+  static void write_xml(libmatroska::KaxInfo &segmentinfo, mm_io_c &out);
   static kax_info_cptr parse_file(std::string const &file_name, bool throw_on_error = true);
 };
 
