@@ -20,8 +20,6 @@
 #include "common/tags/tags.h"
 #include "common/xml/ebml_converter.h"
 
-using namespace libmatroska;
-
 namespace mtx { namespace xml {
 
 class ebml_tags_converter_c: public ebml_converter_c {
@@ -30,14 +28,14 @@ public:
   virtual ~ebml_tags_converter_c();
 
 protected:
-  virtual void fix_ebml(EbmlMaster &root) const;
-  virtual void fix_tag(KaxTag &tag) const;
+  virtual void fix_ebml(libebml::EbmlMaster &root) const;
+  virtual void fix_tag(libmatroska::KaxTag &tag) const;
 
   void setup_maps();
 
 public:
-  static void write_xml(KaxTags &tags, mm_io_c &out);
-  static std::shared_ptr<KaxTags> parse_file(std::string const &file_name, bool throw_on_error);
+  static void write_xml(libmatroska::KaxTags &tags, mm_io_c &out);
+  static std::shared_ptr<libmatroska::KaxTags> parse_file(std::string const &file_name, bool throw_on_error);
 };
 
 }}
