@@ -82,7 +82,7 @@ static int64_t
 get_chapter_index(int idx,
                   KaxChapterAtom &atom) {
   size_t i;
-  std::string sidx = (boost::format("INDEX %|1$02d|") % idx).str();
+  std::string sidx = fmt::format("INDEX {0:02}", idx);
   for (i = 0; i < atom.ListSize(); i++)
     if (   Is<KaxChapterAtom>(atom[i])
         && (mtx::chapters::get_name(*static_cast<KaxChapterAtom *>(atom[i])) == sidx))
@@ -100,7 +100,7 @@ _print_if_global(mm_io_c &out,
                  KaxTags &tags) {
   std::string global = get_global_tag(name, tuid, tags);
   if (!global.empty())
-    out.puts(boost::format(format) % global);
+    out.puts(fmt::format(format, global));
 }
 
 #define print_if_available(name, format) \
@@ -114,7 +114,7 @@ _print_if_available(mm_io_c &out,
                     KaxTag &tag) {
   std::string value = mtx::tags::get_simple_value(name, tag);
   if (!value.empty() && (value != get_global_tag(name, tuid, tags)))
-    out.puts(boost::format(format) % value);
+    out.puts(fmt::format(format, value));
 }
 
 static void
@@ -127,7 +127,7 @@ print_comments(const char *prefix,
     if (Is<KaxTagSimple>(tag[i])
         && (   (mtx::tags::get_simple_name(*static_cast<KaxTagSimple *>(tag[i])) == "COMMENT")
             || (mtx::tags::get_simple_name(*static_cast<KaxTagSimple *>(tag[i])) == "COMMENTS")))
-      out.puts(boost::format("%1%REM \"%2%\"\n") % prefix % mtx::tags::get_simple_value(*static_cast<KaxTagSimple *>(tag[i])));
+      out.puts(fmt::format("{0}REM \"{1}\"\n", prefix, mtx::tags::get_simple_value(*static_cast<KaxTagSimple *>(tag[i]))));
 }
 
 void
@@ -139,38 +139,38 @@ write_cuesheet(std::string file_name,
   if (chapters.ListSize() == 0)
     return;
 
-  if (hack_engaged(ENGAGE_NO_VARIABLE_DATA))
+  if (mtx::hacks::is_engaged(mtx::hacks::NO_VARIABLE_DATA))
     file_name = "no-variable-data";
 
   out.write_bom("UTF-8");
 
-  print_if_global("CATALOG",        "CATALOG %1%\n"); // until 0.9.6
-  print_if_global("CATALOG_NUMBER", "CATALOG %1%\n"); // 0.9.7 and newer
-  print_if_global("ARTIST",         "PERFORMER \"%1%\"\n");
-  print_if_global("TITLE",          "TITLE \"%1%\"\n");
-  print_if_global("DATE",           "REM DATE \"%1%\"\n"); // until 0.9.6
-  print_if_global("DATE_RELEASED",  "REM DATE \"%1%\"\n"); // 0.9.7 and newer
-  print_if_global("DISCID",         "REM DISCID %1%\n");
+  print_if_global("CATALOG",        "CATALOG {0}\n"); // until 0.9.6
+  print_if_global("CATALOG_NUMBER", "CATALOG {0}\n"); // 0.9.7 and newer
+  print_if_global("ARTIST",         "PERFORMER \"{0}\"\n");
+  print_if_global("TITLE",          "TITLE \"{0}\"\n");
+  print_if_global("DATE",           "REM DATE \"{0}\"\n"); // until 0.9.6
+  print_if_global("DATE_RELEASED",  "REM DATE \"{0}\"\n"); // 0.9.7 and newer
+  print_if_global("DISCID",         "REM DISCID {0}\n");
 
   KaxTag *tag = find_tag_for_track(-1, tuid, 0, tags);
   if (tag)
     print_comments("", *tag, out);
 
-  out.puts(boost::format("FILE \"%1%\" WAVE\n") % file_name);
+  out.puts(fmt::format("FILE \"{0}\" WAVE\n", file_name));
 
   size_t i;
   for (i = 0; i < chapters.ListSize(); i++) {
     KaxChapterAtom &atom =  *static_cast<KaxChapterAtom *>(chapters[i]);
 
-    out.puts(boost::format("  TRACK %|1$02d| AUDIO\n") % (i + 1));
+    out.puts(fmt::format("  TRACK {0:02} AUDIO\n", i + 1));
     tag = find_tag_for_track(i + 1, tuid, mtx::chapters::get_uid(atom), tags);
     if (!tag)
       continue;
 
-    print_if_available("TITLE",               "    TITLE \"%1%\"\n");
-    print_if_available("ARTIST",              "    PERFORMER \"%1%\"\n");
-    print_if_available("ISRC",                "    ISRC %1%\n");
-    print_if_available("CDAUDIO_TRACK_FLAGS", "    FLAGS %1%\n");
+    print_if_available("TITLE",               "    TITLE \"{0}\"\n");
+    print_if_available("ARTIST",              "    PERFORMER \"{0}\"\n");
+    print_if_available("ISRC",                "    ISRC {0}\n");
+    print_if_available("CDAUDIO_TRACK_FLAGS", "    FLAGS {0}\n");
 
     int k;
     for (k = 0; 100 > k; ++k) {
@@ -178,17 +178,17 @@ write_cuesheet(std::string file_name,
       if (-1 == temp_index)
         continue;
 
-      out.puts(boost::format("    INDEX %|1$02d| %|2$02d|:%|3$02d|:%|4$02d|\n")
-               % k
-               % (temp_index / 1000000 / 1000 / 60)
-               % ((temp_index / 1000000 / 1000) % 60)
-               % std::llround(static_cast<double>(temp_index % 1000000000ll) * 75.0 / 1000000000.0));
+      out.puts(fmt::format("    INDEX {0:02} {1:02}:{2:02}:{3:02}\n",
+                           k,
+                            temp_index / 1'000'000 / 1'000  / 60,
+                           (temp_index / 1'000'000 / 1'000) % 60,
+                           std::llround(static_cast<double>(temp_index % 1'000'000'000ll) * 75.0 / 1'000'000'000.0)));
     }
 
-    print_if_available("DATE",          "    REM DATE \"%1%\"\n"); // until 0.9.6
+    print_if_available("DATE",          "    REM DATE \"{0}\"\n"); // until 0.9.6
     // 0.9.7 and newer:
-    print_if_available("DATE_RELEASED", "    REM DATE \"%1%\"\n");
-    print_if_available("GENRE",         "    REM GENRE \"%1%\"\n");
+    print_if_available("DATE_RELEASED", "    REM DATE \"{0}\"\n");
+    print_if_available("GENRE",         "    REM GENRE \"{0}\"\n");
     print_comments("    ", *tag, out);
   }
 }
