@@ -35,7 +35,6 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t id);
   virtual bool is_providing_timestamps() const {
@@ -45,5 +44,7 @@ public:
   static int probe_file(mm_io_c &in, uint64_t size, int64_t probe_range, int num_headers, bool require_zero_offset = false);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   static int find_valid_headers(mm_io_c &in, int64_t probe_range, int num_headers);
 };
