@@ -65,7 +65,7 @@ coreaudio_reader_c::~coreaudio_reader_c() {
 void
 coreaudio_reader_c::identify() {
   if (!m_supported) {
-    id_result_container_unsupported(m_in->get_file_name(), (boost::format("CoreAudio (%1%)") % m_codec_name).str());
+    id_result_container_unsupported(m_in->get_file_name(), fmt::format("CoreAudio ({0})", m_codec_name));
     return;
   }
 
@@ -99,52 +99,48 @@ coreaudio_reader_c::read_headers() {
 void
 coreaudio_reader_c::dump_headers()
   const {
-  mxdebug(boost::format("File '%1%' CoreAudio header dump\n"
-                        "  'desc' chunk:\n"
-                        "    codec:             %2%\n"
-                        "    supported:         %3%\n"
-                        "    sample_rate:       %4%\n"
-                        "    flags:             %5%\n"
-                        "    bytes_per_packet:  %6%\n"
-                        "    frames_per_packet: %7%\n"
-                        "    channels:          %8%\n"
-                        "    bits_per_sample:   %9%\n"
-                        "  'kuki' chunk:\n"
-                        "    magic cookie:      %10%\n"
-                        )
-          % m_ti.m_fname
-          % m_codec_name % m_supported % m_sample_rate % m_flags % m_bytes_per_packet % m_frames_per_packet % m_channels % m_bits_per_sample
-          % (m_magic_cookie ? (boost::format("present, size %1%") % m_magic_cookie->get_size()).str() : "not present"s)
-          );
+  mxdebug(fmt::format("File '{0}' CoreAudio header dump\n"
+                      "  'desc' chunk:\n"
+                      "    codec:             {1}\n"
+                      "    supported:         {2}\n"
+                      "    sample_rate:       {3}\n"
+                      "    flags:             {4}\n"
+                      "    bytes_per_packet:  {5}\n"
+                      "    frames_per_packet: {6}\n"
+                      "    channels:          {7}\n"
+                      "    bits_per_sample:   {8}\n"
+                      "  'kuki' chunk:\n"
+                      "    magic cookie:      {9}\n",
+                      m_ti.m_fname,
+                      m_codec_name, m_supported, m_sample_rate, m_flags, m_bytes_per_packet, m_frames_per_packet, m_channels, m_bits_per_sample,
+                      m_magic_cookie ? fmt::format("present, size {0}", m_magic_cookie->get_size()) : "not present"s));
 
   if (m_codec.is(codec_c::type_e::A_ALAC) && m_magic_cookie && (m_magic_cookie->get_size() >= sizeof(mtx::alac::codec_config_t))) {
     auto cfg = reinterpret_cast<mtx::alac::codec_config_t *>(m_magic_cookie->get_buffer());
 
-    mxdebug(boost::format("ALAC magic cookie dump:\n"
-                          "  frame length:         %1%\n"
-                          "  compatible version:   %2%\n"
-                          "  bit depth:            %3%\n"
-                          "  rice history mult:    %4%\n"
-                          "  rice initial history: %5%\n"
-                          "  rice limit:           %6%\n"
-                          "  num channels:         %7%\n"
-                          "  max run:              %8%\n"
-                          "  max frame bytes:      %9%\n"
-                          "  avg bit rate:         %10%\n"
-                          "  sample rate:          %11%\n"
-                          )
-                          % get_uint32_be(&cfg->frame_length)
-                          % static_cast<unsigned int>(cfg->compatible_version)
-                          % static_cast<unsigned int>(cfg->bit_depth)
-                          % static_cast<unsigned int>(cfg->rice_history_mult)
-                          % static_cast<unsigned int>(cfg->rice_initial_history)
-                          % static_cast<unsigned int>(cfg->rice_limit)
-                          % static_cast<unsigned int>(cfg->num_channels)
-                          % get_uint16_be(&cfg->max_run)
-                          % get_uint32_be(&cfg->max_frame_bytes)
-                          % get_uint32_be(&cfg->avg_bit_rate)
-                          % get_uint32_be(&cfg->sample_rate)
-            );
+    mxdebug(fmt::format("ALAC magic cookie dump:\n"
+                        "  frame length:         {0}\n"
+                        "  compatible version:   {1}\n"
+                        "  bit depth:            {2}\n"
+                        "  rice history mult:    {3}\n"
+                        "  rice initial history: {4}\n"
+                        "  rice limit:           {5}\n"
+                        "  num channels:         {6}\n"
+                        "  max run:              {7}\n"
+                        "  max frame bytes:      {8}\n"
+                        "  avg bit rate:         {9}\n"
+                        "  sample rate:          {10}\n",
+                        get_uint32_be(&cfg->frame_length),
+                        static_cast<unsigned int>(cfg->compatible_version),
+                        static_cast<unsigned int>(cfg->bit_depth),
+                        static_cast<unsigned int>(cfg->rice_history_mult),
+                        static_cast<unsigned int>(cfg->rice_initial_history),
+                        static_cast<unsigned int>(cfg->rice_limit),
+                        static_cast<unsigned int>(cfg->num_channels),
+                        get_uint16_be(&cfg->max_run),
+                        get_uint32_be(&cfg->max_frame_bytes),
+                        get_uint32_be(&cfg->avg_bit_rate),
+                        get_uint32_be(&cfg->sample_rate)));
   }
 }
 
@@ -205,7 +201,7 @@ coreaudio_reader_c::scan_chunks() {
       chunk.m_size          = std::min<uint64_t>(chunk.m_size ? chunk.m_size : std::numeric_limits<uint64_t>::max(), file_size);
       chunk.m_data_position = m_in->getFilePointer();
 
-      mxdebug_if(m_debug_chunks,boost::format("scan_chunks() new chunk at %1% data position %4% type '%2%' size %3%\n") % chunk.m_position % get_displayable_string(chunk.m_type) % chunk.m_size % chunk.m_data_position);
+      mxdebug_if(m_debug_chunks,fmt::format("scan_chunks() new chunk at {0} data position {3} type '{1}' size {2}\n", chunk.m_position, get_displayable_string(chunk.m_type), chunk.m_size, chunk.m_data_position));
 
       m_chunks.push_back(chunk);
       m_in->setFilePointer(chunk.m_size, seek_current);
@@ -216,9 +212,9 @@ coreaudio_reader_c::scan_chunks() {
 }
 
 void
-coreaudio_reader_c::debug_error_and_throw(boost::format const &format)
+coreaudio_reader_c::debug_error_and_throw(std::string const &message)
   const {
-  mxdebug_if(m_debug_headers, boost::format("%1%\n") % format);
+  mxdebug_if(m_debug_headers, fmt::format("{0}\n", message));
   throw mtx::input::header_parsing_x{};
 }
 
@@ -229,7 +225,7 @@ coreaudio_reader_c::find_chunk(std::string const &type,
   auto chunk = std::find_if(start, m_chunks.end(), [&type](auto const &chunk) { return chunk.m_type == type; });
 
   if (throw_on_error && (chunk == m_chunks.end()))
-    debug_error_and_throw(boost::format("Chunk type '%1%' not found") % type);
+    debug_error_and_throw(fmt::format("Chunk type '{0}' not found", type));
 
   return chunk;
 }
@@ -243,7 +239,7 @@ coreaudio_reader_c::read_chunk(std::string const &type,
       return nullptr;
 
     if (!chunk->m_size)
-      debug_error_and_throw(boost::format("Chunk '%1%' at %2% has zero size") % type % chunk->m_position);
+      debug_error_and_throw(fmt::format("Chunk '{0}' at {1} has zero size", type, chunk->m_position));
 
     m_in->setFilePointer(chunk->m_data_position);
 
@@ -254,13 +250,13 @@ coreaudio_reader_c::read_chunk(std::string const &type,
     return mem;
 
   } catch (mtx::mm_io::exception &ex) {
-    debug_error_and_throw(boost::format("I/O error reading the '%1%' chunk: %2%") % type % ex);
+    debug_error_and_throw(fmt::format("I/O error reading the '{0}' chunk: {1}", type, ex));
 
   } catch (mtx::input::header_parsing_x &) {
     throw;
 
   } catch (...) {
-    debug_error_and_throw(boost::format("Generic error reading the '%1%' chunk") % type);
+    debug_error_and_throw(fmt::format("Generic error reading the '{0}' chunk", type));
   }
 
   return nullptr;
@@ -292,9 +288,9 @@ coreaudio_reader_c::parse_desc_chunk() {
       m_supported = true;
 
   } catch (mtx::mm_io::exception &ex) {
-    debug_error_and_throw(boost::format("I/O exception during 'desc' parsing: %1%") % ex.what());
+    debug_error_and_throw(fmt::format("I/O exception during 'desc' parsing: {0}", ex.what()));
   } catch (...) {
-    debug_error_and_throw(boost::format("Unknown exception during 'desc' parsing"));
+    debug_error_and_throw(fmt::format("Unknown exception during 'desc' parsing"));
   }
 }
 
@@ -312,7 +308,7 @@ coreaudio_reader_c::parse_pakt_chunk() {
     auto position     = data_chunk->m_data_position + 4; // skip the "edit count" field
     uint64_t timestamp = 0;
 
-    mxdebug_if(m_debug_headers, boost::format("Number of packets: %1%, number of frames: %2%\n") % num_packets % num_frames);
+    mxdebug_if(m_debug_headers, fmt::format("Number of packets: {0}, number of frames: {1}\n", num_packets, num_frames));
 
     for (auto packet_num = 0u; packet_num < num_packets; ++packet_num) {
       coreaudio_packet_t packet;
@@ -327,17 +323,17 @@ coreaudio_reader_c::parse_pakt_chunk() {
       m_packets.push_back(packet);
 
       mxdebug_if(m_debug_packets,
-                 boost::format("  %4%) position %1% size %2% raw duration %3% raw timestamp %6% duration %7% timestamp %8% position in 'pakt' %5%\n")
-                 % packet.m_position % packet.m_size % packet.m_duration % packet_num % mem.getFilePointer() % packet.m_timestamp
-                 % format_timestamp(packet.m_duration * m_frames_to_timestamp) % format_timestamp(packet.m_timestamp * m_frames_to_timestamp));
+                 fmt::format("  {3}) position {0} size {1} raw duration {2} raw timestamp {5} duration {6} timestamp {7} position in 'pakt' {4}\n",
+                             packet.m_position, packet.m_size, packet.m_duration, packet_num, mem.getFilePointer(), packet.m_timestamp,
+                             format_timestamp(packet.m_duration * m_frames_to_timestamp), format_timestamp(packet.m_timestamp * m_frames_to_timestamp)));
     }
 
-    mxdebug_if(m_debug_headers, boost::format("Final value for 'position': %1% data chunk end: %2%\n") % position % (data_chunk->m_position + 12 + data_chunk->m_size));
+    mxdebug_if(m_debug_headers, fmt::format("Final value for 'position': {0} data chunk end: {1}\n", position, data_chunk->m_position + 12 + data_chunk->m_size));
 
   } catch (mtx::mm_io::exception &ex) {
-    debug_error_and_throw(boost::format("I/O exception during 'pakt' parsing: %1%") % ex.what());
+    debug_error_and_throw(fmt::format("I/O exception during 'pakt' parsing: {0}", ex.what()));
   } catch (...) {
-    debug_error_and_throw(boost::format("Unknown exception during 'pakt' parsing"));
+    debug_error_and_throw(fmt::format("Unknown exception during 'pakt' parsing"));
   }
 
   m_current_packet = m_packets.begin();
@@ -359,11 +355,11 @@ coreaudio_reader_c::parse_kuki_chunk() {
 void
 coreaudio_reader_c::handle_alac_magic_cookie(memory_cptr chunk) {
   if (chunk->get_size() < sizeof(mtx::alac::codec_config_t))
-    debug_error_and_throw(boost::format("Invalid ALAC magic cookie; size: %1% < %2%") % chunk->get_size() % sizeof(mtx::alac::codec_config_t));
+    debug_error_and_throw(fmt::format("Invalid ALAC magic cookie; size: {0} < {1}", chunk->get_size(), sizeof(mtx::alac::codec_config_t)));
 
   // Convert old-style magic cookie
   if (!memcmp(chunk->get_buffer() + 4, "frmaalac", 8)) {
-    mxdebug_if(m_debug_headers, boost::format("Converting old-style ALAC magic cookie with size %1% to new style\n") % chunk->get_size());
+    mxdebug_if(m_debug_headers, fmt::format("Converting old-style ALAC magic cookie with size {0} to new style\n", chunk->get_size()));
 
     auto const old_style_min_size
       = 12                            // format atom
@@ -371,7 +367,7 @@ coreaudio_reader_c::handle_alac_magic_cookie(memory_cptr chunk) {
       + sizeof(mtx::alac::codec_config_t); // the magic cookie itself
 
     if (chunk->get_size() < old_style_min_size)
-      debug_error_and_throw(boost::format("Invalid old-style ALAC magic cookie; size: %1% < %2%") % chunk->get_size() % old_style_min_size);
+      debug_error_and_throw(fmt::format("Invalid old-style ALAC magic cookie; size: {0} < {1}", chunk->get_size(), old_style_min_size));
 
     m_magic_cookie = memory_c::clone(chunk->get_buffer() + 12 + 12, sizeof(mtx::alac::codec_config_t));
 
@@ -379,5 +375,5 @@ coreaudio_reader_c::handle_alac_magic_cookie(memory_cptr chunk) {
     m_magic_cookie = chunk;
 
 
-  mxdebug_if(m_debug_headers, boost::format("Magic cookie size: %1%\n") % m_magic_cookie->get_size());
+  mxdebug_if(m_debug_headers, fmt::format("Magic cookie size: {0}\n", m_magic_cookie->get_size()));
 }
