@@ -33,7 +33,6 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t id);
   virtual bool is_providing_timestamps() const {
@@ -41,4 +40,7 @@ public:
   }
 
   static int probe_file(mm_io_c &in, uint64_t size);
+
+protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
 };
