@@ -64,16 +64,17 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t id);
   virtual bool is_providing_timestamps() const {
     return false;
   }
 
-  static int probe_file(mm_io_c *in, uint64_t size, bool strict_mode = false);
+  static int probe_file(mm_io_c &in, uint64_t size, bool strict_mode = false);
   static chunks_t scan_chunks(mm_io_c &in);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual int decode_buffer(size_t length);
 };
