@@ -46,6 +46,7 @@ private:
   FLAC__StreamMetadata_StreamInfo stream_info;
   unsigned int m_attachment_id{};
   debugging_option_c m_debug{"flac_reader|flac"};
+  int64_t tag_size_start{}, tag_size_end{};
 
 public:
   flac_reader_c(const track_info_c &ti, const mm_io_cptr &in);
@@ -56,7 +57,6 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t id);
   virtual bool is_providing_timestamps() const {
@@ -74,6 +74,8 @@ public:
   virtual FLAC__bool flac_eof_cb();
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual bool parse_file(bool for_identification_only);
   virtual void handle_picture_metadata(FLAC__StreamMetadata const *metadata);
   virtual void handle_stream_info_metadata(FLAC__StreamMetadata const *metadata);
