@@ -404,7 +404,7 @@ struct qt_atom_t {
   {
   }
 
-  qt_atom_t to_parent() {
+  qt_atom_t to_parent() const {
     qt_atom_t parent;
 
     parent.fourcc = fourcc;
@@ -417,7 +417,7 @@ struct qt_atom_t {
 inline std::ostream &
 operator <<(std::ostream &out,
             qt_atom_t const &atom) {
-  out << (boost::format("<%1% at %2% size %3% hsize %4%>") % atom.fourcc % atom.pos % atom.size % atom.hsize);
+  out << fmt::format("<{0} at {1} size {2} hsize {3}>", atom.fourcc, atom.pos, atom.size, atom.hsize);
   return out;
 }
 
@@ -569,4 +569,6 @@ protected:
   virtual void detect_interleaving();
 
   virtual std::string read_string_atom(qt_atom_t atom, size_t num_skipped);
+
+  virtual void process_atom(qt_atom_t const &parent, int level, std::function<void(qt_atom_t const &)> const &handler);
 };
