@@ -97,8 +97,6 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
-  virtual int get_progress();
   virtual void identify();
   virtual void create_packetizers();
   virtual void create_packetizer(int64_t tid);
@@ -107,6 +105,8 @@ public:
   static int probe_file(mm_io_c &in, uint64_t size);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual void parse_headers();
   virtual real_demuxer_cptr find_demuxer(unsigned int id);
   virtual void assemble_video_packet(real_demuxer_cptr dmx, rmff_frame_t *frame);
@@ -115,8 +115,8 @@ protected:
   virtual void set_dimensions(real_demuxer_cptr dmx, unsigned char *buffer, int size);
   virtual void get_information_from_data();
   virtual void deliver_aac_frames(real_demuxer_cptr dmx, memory_c &mem);
-  virtual void queue_audio_frames(real_demuxer_cptr dmx, memory_c &mem, uint64_t timestamp, uint32_t flags);
-  virtual void queue_one_audio_frame(real_demuxer_cptr dmx, memory_c &mem, uint64_t timestamp, uint32_t flags);
+  virtual void queue_audio_frames(real_demuxer_cptr dmx, memory_cptr const &mem, uint64_t timestamp, uint32_t flags);
+  virtual void queue_one_audio_frame(real_demuxer_cptr dmx, memory_cptr const &mem, uint64_t timestamp, uint32_t flags);
   virtual void deliver_audio_frames(real_demuxer_cptr dmx, uint64_t duration);
 
   virtual void create_audio_packetizer(real_demuxer_cptr dmx);
