@@ -49,10 +49,10 @@ ssa_reader_c::read_headers() {
   if (!ssa_reader_c::probe_file(*text_in, 0))
     throw mtx::input::invalid_format_x();
 
-  charset_converter_cptr cc_utf8 = text_in->get_byte_order() != BO_NONE   ? charset_converter_c::init("UTF-8")
-                                 : mtx::includes(m_ti.m_sub_charsets,  0) ? charset_converter_c::init(m_ti.m_sub_charsets[ 0])
-                                 : mtx::includes(m_ti.m_sub_charsets, -1) ? charset_converter_c::init(m_ti.m_sub_charsets[-1])
-                                 :                                          g_cc_local_utf8;
+  auto  cc_utf8 = text_in->get_byte_order() != BO_NONE   ? charset_converter_c::init("UTF-8")
+                : mtx::includes(m_ti.m_sub_charsets,  0) ? charset_converter_c::init(m_ti.m_sub_charsets[ 0])
+                : mtx::includes(m_ti.m_sub_charsets, -1) ? charset_converter_c::init(m_ti.m_sub_charsets[-1])
+                :                                          charset_converter_cptr{};
 
   m_ti.m_id  = 0;
   m_subs     = std::make_shared<ssa_parser_c>(*this, text_in, m_ti.m_fname, 0);
@@ -61,6 +61,8 @@ ssa_reader_c::read_headers() {
   m_subs->set_charset_converter(cc_utf8);
   m_subs->parse();
 
+  m_bytes_to_process = m_subs->get_total_byte_size();
+
   show_demuxer_info();
 }
 
@@ -73,24 +75,29 @@ ssa_reader_c::create_packetizer(int64_t) {
     return;
 
   m_ti.m_private_data = memory_c::clone(m_subs->get_global());
-  add_packetizer(new textsubs_packetizer_c(this, m_ti, m_subs->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA, false, false));
+  add_packetizer(new textsubs_packetizer_c(this, m_ti, m_subs->is_ass() ?  MKV_S_TEXTASS : MKV_S_TEXTSSA));
   show_packetizer_info(0, PTZR0);
 }
 
 file_status_e
 ssa_reader_c::read(generic_packetizer_c *,
                    bool) {
-  if (!m_subs->empty())
+  if (!m_subs->empty()) {
+    m_bytes_processed += m_subs->get_next_byte_size();
     m_subs->process((textsubs_packetizer_c *)PTZR0);
+  }
 
   return m_subs->empty() ? flush_packetizers() : FILE_STATUS_MOREDATA;
 }
 
-int
+int64_t
 ssa_reader_c::get_progress() {
-  int num_entries = m_subs->get_num_entries();
+  return m_bytes_processed;
+}
 
-  return 0 == num_entries ? 100 : 100 * m_subs->get_num_processed() / num_entries;
+int64_t
+ssa_reader_c::get_maximum_progress() {
+  return m_bytes_to_process;
 }
 
 void
