@@ -61,7 +61,7 @@ tta_reader_c::read_headers() {
   try {
     int tag_size = mtx::id3::skip_v2_tag(*m_in);
     if (0 > tag_size)
-      mxerror_fn(m_ti.m_fname, boost::format(Y("tta_reader: tag_size < 0 in the c'tor. %1%\n")) % BUGMSG);
+      mxerror_fn(m_ti.m_fname, fmt::format(Y("tta_reader: tag_size < 0 in the c'tor. {0}\n"), BUGMSG));
     m_size -= tag_size;
 
     if (m_in->read(&header, sizeof(tta_file_header_t)) != sizeof(tta_file_header_t))
@@ -83,10 +83,10 @@ tta_reader_c::read_headers() {
     } while (seek_sum < m_size);
 
     mxverb(2,
-           boost::format("tta: ch %1% bps %2% sr %3% dl %4% seek_sum %5% size %6% num %7%\n")
-           % get_uint16_le(&header.channels)    % get_uint16_le(&header.bits_per_sample)
-           % get_uint32_le(&header.sample_rate) % get_uint32_le(&header.data_length)
-           % seek_sum      % m_size             % seek_points.size());
+           fmt::format("tta: ch {0} bps {1} sr {2} dl {3} seek_sum {4} size {5} num {6}\n",
+                       get_uint16_le(&header.channels),    get_uint16_le(&header.bits_per_sample),
+                       get_uint32_le(&header.sample_rate), get_uint32_le(&header.data_length),
+                       seek_sum, m_size, seek_points.size()));
 
     if (seek_sum != m_size)
       mxerror_fn(m_ti.m_fname, Y("The seek table in this TTA file seems to be broken.\n"));
@@ -129,7 +129,7 @@ tta_reader_c::read(generic_packetizer_c *,
 
   if (seek_points.size() <= pos) {
     double samples_left = (double)get_uint32_le(&header.data_length) - (seek_points.size() - 1) * TTA_FRAME_TIME * get_uint32_le(&header.sample_rate);
-    mxverb(2, boost::format("tta: samples_left %1%\n") % samples_left);
+    mxverb(2, fmt::format("tta: samples_left {0}\n", samples_left));
 
     PTZR0->process(new packet_t(mem, -1, std::llround(samples_left * 1000000000.0 / get_uint32_le(&header.sample_rate))));
   } else
