@@ -35,9 +35,11 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
   static int probe_file(mm_io_c &in, uint64_t size);
+
+protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
 };
