@@ -113,7 +113,7 @@ vc1_es_reader_c::read(generic_packetizer_c *,
 void
 vc1_es_reader_c::identify() {
   auto info = mtx::id::info_c{};
-  info.add(mtx::id::pixel_dimensions, boost::format("%1%x%2%") % m_seqhdr.pixel_width % m_seqhdr.pixel_height);
+  info.add(mtx::id::pixel_dimensions, fmt::format("{0}x{1}", m_seqhdr.pixel_width, m_seqhdr.pixel_height));
 
   id_result_container();
   id_result_track(0, ID_RESULT_TRACK_VIDEO, codec_c::get_name(codec_c::type_e::V_VC1, "VC1"), info.get());
