@@ -55,7 +55,8 @@ private:
   mm_text_io_cptr m_idx_file;
   mm_file_io_cptr m_sub_file;
   int version;
-  int64_t num_indices, indices_processed, delay;
+  int64_t delay;
+  int64_t m_bytes_to_process{}, m_bytes_processed{};
   std::string idx_data;
 
   std::vector<vobsub_track_c *> tracks;
@@ -72,12 +73,12 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizers();
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
-  virtual int get_progress();
+  virtual int64_t get_progress() override;
+  virtual int64_t get_maximum_progress() override;
   virtual bool is_simple_subtitle_container() {
     return true;
   }
@@ -85,6 +86,8 @@ public:
   static int probe_file(mm_io_c &in, uint64_t size);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual void parse_headers();
   virtual file_status_e flush_packetizers();
   virtual int deliver_packet(unsigned char *buf, int size, int64_t timestamp, int64_t default_duration, generic_packetizer_c *ptzr);
