@@ -22,6 +22,7 @@ class webvtt_reader_c: public generic_reader_c {
 private:
   mm_text_io_cptr m_text_in;
   webvtt_parser_cptr m_parser;
+  int64_t m_bytes_to_process{}, m_bytes_processed{};
 
 public:
   webvtt_reader_c(const track_info_c &ti, const mm_io_cptr &in);
@@ -32,10 +33,10 @@ public:
   }
 
   virtual void read_headers();
-  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
-  virtual int get_progress();
+  virtual int64_t get_progress() override;
+  virtual int64_t get_maximum_progress() override;
   virtual bool is_simple_subtitle_container() {
     return true;
   }
@@ -43,5 +44,7 @@ public:
   static int probe_file(mm_text_io_c &in, uint64_t size);
 
 protected:
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false) override;
+
   virtual void parse_file();
 };
