@@ -30,8 +30,6 @@ namespace libmatroska {
 class KaxTrackEntry;
 }
 
-using namespace libmatroska;
-
 class generic_reader_c;
 
 enum connection_result_e {
@@ -44,6 +42,15 @@ enum connection_result_e {
 using packet_cptr_di = std::deque<packet_cptr>::iterator;
 
 class generic_packetizer_c {
+public:
+  enum display_dimensions_unit_e {
+    ddu_pixels       = 0,
+    ddu_centimeters  = 1,
+    ddu_inches       = 2,
+    ddu_aspect_ratio = 3,
+    ddu_unknown      = 4,
+  };
+
 protected:
   int m_num_packets;
   std::deque<packet_cptr> m_packet_queue, m_deferred_packets;
@@ -52,7 +59,7 @@ protected:
   int64_t m_free_refs, m_next_free_refs, m_enqueued_bytes;
   int64_t m_safety_last_timestamp, m_safety_last_duration;
 
-  KaxTrackEntry *m_track_entry;
+  libmatroska::KaxTrackEntry *m_track_entry;
 
   // Header entries. Can be set via set_XXX and will be 'rendered'
   // by set_headers().
@@ -71,7 +78,7 @@ protected:
   float m_haudio_sampling_freq, m_haudio_output_sampling_freq;
   int m_haudio_channels, m_haudio_bit_depth;
 
-  int m_hvideo_interlaced_flag, m_hvideo_pixel_width, m_hvideo_pixel_height, m_hvideo_display_width, m_hvideo_display_height;
+  int m_hvideo_interlaced_flag, m_hvideo_pixel_width, m_hvideo_pixel_height, m_hvideo_display_width, m_hvideo_display_height, m_hvideo_display_unit;
 
   compression_method_e m_hcompression;
   compressor_ptr m_compressor;
@@ -153,7 +160,7 @@ public:
     m_last_cue_timestamp = timestamp;
   }
 
-  virtual KaxTrackEntry *get_track_entry() const {
+  virtual libmatroska::KaxTrackEntry *get_track_entry() const {
     return m_track_entry;
   }
   virtual int get_track_num() const {
@@ -207,7 +214,8 @@ public:
   virtual void set_video_pixel_dimensions(int width, int height);
   virtual void set_video_display_width(int width);
   virtual void set_video_display_height(int height);
-  virtual void set_video_display_dimensions(int width, int height, option_source_e source);
+  virtual void set_video_display_unit(int unit);
+  virtual void set_video_display_dimensions(int width, int height, int unit, option_source_e source);
   virtual void set_video_aspect_ratio(double aspect_ratio, bool is_factor, option_source_e source);
   virtual void set_video_pixel_cropping(int left, int top, int right, int bottom, option_source_e source);
   virtual void set_video_pixel_cropping(const pixel_crop_t &cropping, option_source_e source);
@@ -232,7 +240,7 @@ public:
   virtual void set_video_projection_pose_roll(double value, option_source_e source);
   virtual void set_video_field_order(uint64_t order, option_source_e source);
   virtual void set_video_stereo_mode(stereo_mode_c::mode stereo_mode, option_source_e source);
-  virtual void set_video_stereo_mode_impl(EbmlMaster &video, stereo_mode_c::mode stereo_mode);
+  virtual void set_video_stereo_mode_impl(libebml::EbmlMaster &video, stereo_mode_c::mode stereo_mode);
 
   virtual void set_as_default_track(int type, int priority);
 
@@ -245,6 +253,8 @@ public:
       m_hcompression = method;
   }
 
+  virtual void set_video_colour_space(memory_cptr const &value, option_source_e source);
+
   virtual void force_duration_on_last_packet();
 
   virtual translatable_string_c get_format_name() const = 0;
