@@ -22,6 +22,8 @@ public:
   std::vector<int64_t> m_durations;
   generic_packetizer_c *m_source;
   bool m_more_data, m_duration_mandatory, m_has_discard_padding;
+  int64_t m_expected_next_timestamp{-1};
+  static debugging_option_c ms_gap_detection;
 
   render_groups_c(generic_packetizer_c *source)
     : m_source(source)
@@ -30,6 +32,22 @@ public:
     , m_has_discard_padding{}
   {
   }
+
+  bool follows_gap(packet_t &pack) const {
+    // return false;
+
+    if (-1 == m_expected_next_timestamp)
+      return false;
+
+    auto diff   = timestamp_c::ns(pack.assigned_timestamp - m_expected_next_timestamp).abs();
+    auto result = diff > timestamp_c::ms(2);
+
+    mxdebug_if(ms_gap_detection,
+               fmt::format("follows gap {0} expected next: {1} assigned {2}  {3}\n",
+                           result, format_timestamp(m_expected_next_timestamp), format_timestamp(pack.assigned_timestamp), diff));
+
+    return result;
+  }
 };
 using render_groups_cptr = std::shared_ptr<render_groups_c>;
 
@@ -52,7 +70,6 @@ public:
   bool discarding{}, splitting_and_processed_fully{};
 
   chapter_generation_mode_e chapter_generation_mode{chapter_generation_mode_e::none};
-  translatable_string_c chapter_generation_name_template{YT("Chapter <NUM:2>")};
   timestamp_c chapter_generation_interval, chapter_generation_last_generated;
   generic_packetizer_c *chapter_generation_reference_track{};
   unsigned int chapter_generation_number{};
