@@ -7,8 +7,6 @@
 #include <QThread>
 #include <QTranslator>
 
-#include <boost/optional.hpp>
-
 #include "common/command_line.h"
 #include "common/extern_data.h"
 #include "common/fs_sys_helpers.h"
@@ -71,10 +69,6 @@ App::App(int &argc,
   ignore_unique_numbers(UNIQUE_CHAPTER_IDS);
   ignore_unique_numbers(UNIQUE_EDITION_IDS);
 
-  QCoreApplication::setOrganizationName("bunkus.org");
-  QCoreApplication::setOrganizationDomain("bunkus.org");
-  QCoreApplication::setApplicationName("mkvtoolnix-gui");
-
 #ifdef SYS_WINDOWS
   QApplication::setStyle(Q("windowsvista"));
 #endif
@@ -215,7 +209,6 @@ App::reinitializeLanguageLists() {
 
   initializeLanguageLists();
 
-  ::mtx::kax_info_c::init_common_formats();
   kax_element_names_c::reset();
 }
 
