@@ -41,7 +41,7 @@ public:
   void removeTree(QModelIndex const &idx);
 
   void updateRow(QModelIndex const &idx);
-  void populate(libebml::EbmlMaster &master);
+  void populate(libebml::EbmlMaster &master, bool append);
   void reset();
   void retranslateUi();
 
@@ -59,6 +59,8 @@ public:
   virtual bool canDropMimeData(QMimeData const *data, Qt::DropAction action, int row, int column, QModelIndex const &parent) const override;
   virtual bool dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent) override;
 
+  ChaptersPtr cloneSubtreeForRetrieval(QModelIndex const &topIdx);
+
 protected:
   void setEditionRowText(QList<QStandardItem *> const &rowItems);
   void setChapterRowText(QList<QStandardItem *> const &rowItems);
@@ -67,6 +69,10 @@ protected:
   void cloneElementsForRetrieval(QModelIndex const &parentIdx, libebml::EbmlMaster &target);
   void duplicateTree(QModelIndex const &destParentIdx, int destRow, QModelIndex const &srcIdx);
 
+  void collectUsedEditionAndChapterUIDs(QModelIndex const &parentIdx, QSet<uint64_t> &usedEditionUIDs, QSet<uint64_t> &usedChapterUIDs);
+  void fixEditionAndChapterUIDs(EbmlMaster &master);
+  void fixEditionAndChapterUIDs(EbmlMaster &master, QSet<uint64_t> &usedEditionUIDs, QSet<uint64_t> &usedChapterUIDs);
+
   qulonglong registerElement(std::shared_ptr<libebml::EbmlMaster> const &element);
   qulonglong registryIdFromItem(QStandardItem *item);
 
