@@ -42,19 +42,21 @@ MassModificationDialog::setupUi(QStringList const &additionalLanguages,
   m_ui->cbCountry->setAdditionalItems(additionalCountryCodes).setup(true, QY("– Set to none –"));
 
   auto mw = MainWindow::get();
-  connect(m_ui->cbShift,           &QCheckBox::toggled,                                                          this,              &MassModificationDialog::verifyOptions);
-  connect(m_ui->leShiftBy,         &QLineEdit::textChanged,                                                      this,              &MassModificationDialog::verifyOptions);
-  connect(m_ui->cbMultiply,        &QCheckBox::toggled,                                                          this,              &MassModificationDialog::verifyOptions);
-  connect(m_ui->dsbMultiplyBy,     static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this,              &MassModificationDialog::verifyOptions);
-  connect(m_ui->cbSetLanguage,     &QCheckBox::toggled,                                                          m_ui->cbLanguage,  &QComboBox::setEnabled);
-  connect(m_ui->cbSetCountry,      &QCheckBox::toggled,                                                          m_ui->cbCountry,   &QComboBox::setEnabled);
-  connect(m_ui->cbConstrictExpand, &QCheckBox::toggled,                                                          m_ui->rbConstrict, &QRadioButton::setEnabled);
-  connect(m_ui->cbConstrictExpand, &QCheckBox::toggled,                                                          m_ui->rbExpand,    &QRadioButton::setEnabled);
-  connect(m_ui->buttonBox,         &QDialogButtonBox::accepted,                                                  this,              &MassModificationDialog::accept);
-  connect(m_ui->buttonBox,         &QDialogButtonBox::rejected,                                                  this,              &MassModificationDialog::reject);
+  connect(m_ui->cbShift,               &QCheckBox::toggled,                                                          this,                        &MassModificationDialog::verifyOptions);
+  connect(m_ui->leShiftBy,             &QLineEdit::textChanged,                                                      this,                        &MassModificationDialog::verifyOptions);
+  connect(m_ui->cbMultiply,            &QCheckBox::toggled,                                                          this,                        &MassModificationDialog::verifyOptions);
+  connect(m_ui->dsbMultiplyBy,         static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this,                        &MassModificationDialog::verifyOptions);
+  connect(m_ui->cbSetLanguage,         &QCheckBox::toggled,                                                          m_ui->cbLanguage,            &QComboBox::setEnabled);
+  connect(m_ui->cbSetCountry,          &QCheckBox::toggled,                                                          m_ui->cbCountry,             &QComboBox::setEnabled);
+  connect(m_ui->cbConstrictExpand,     &QCheckBox::toggled,                                                          m_ui->rbConstrict,           &QRadioButton::setEnabled);
+  connect(m_ui->cbConstrictExpand,     &QCheckBox::toggled,                                                          m_ui->rbExpand,              &QRadioButton::setEnabled);
+  connect(m_ui->cbSetEndTimestamps,    &QCheckBox::toggled,                                                          m_ui->cbRemoveEndTimestamps, &QRadioButton::setDisabled);
+  connect(m_ui->cbRemoveEndTimestamps, &QCheckBox::toggled,                                                          m_ui->cbSetEndTimestamps,    &QRadioButton::setDisabled);
+  connect(m_ui->buttonBox,             &QDialogButtonBox::accepted,                                                  this,                        &MassModificationDialog::accept);
+  connect(m_ui->buttonBox,             &QDialogButtonBox::rejected,                                                  this,                        &MassModificationDialog::reject);
 
-  connect(mw,                      &MainWindow::preferencesChanged,                                              m_ui->cbLanguage,  &Util::ComboBoxBase::reInitialize);
-  connect(mw,                      &MainWindow::preferencesChanged,                                              m_ui->cbCountry,   &Util::ComboBoxBase::reInitialize);
+  connect(mw,                          &MainWindow::preferencesChanged,                                              m_ui->cbLanguage,            &Util::ComboBoxBase::reInitialize);
+  connect(mw,                          &MainWindow::preferencesChanged,                                              m_ui->cbCountry,             &Util::ComboBoxBase::reInitialize);
 
   m_ui->leShiftBy->setEnabled(false);
   m_ui->dsbMultiplyBy->setEnabled(false);
@@ -94,14 +96,16 @@ MassModificationDialog::actions()
   const {
   auto result = Actions{};
 
-  if (m_ui->cbShift->isChecked())                                             result |= Action::Shift;
-  if (m_ui->cbSort->isChecked())                                              result |= Action::Sort;
-  if (m_ui->cbConstrictExpand->isChecked() && m_ui->rbConstrict->isChecked()) result |= Action::Constrict;
-  if (m_ui->cbConstrictExpand->isChecked() && m_ui->rbExpand->isChecked())    result |= Action::Expand;
-  if (m_ui->cbSetLanguage->isChecked())                                       result |= Action::SetLanguage;
-  if (m_ui->cbSetCountry->isChecked())                                        result |= Action::SetCountry;
-  if (m_ui->cbMultiply->isChecked())                                          result |= Action::Multiply;
-  if (m_ui->cbSetEndTimestamps->isChecked())                                  result |= Action::SetEndTimestamps;
+  if (m_ui->cbShift->isChecked())                                                           result |= Action::Shift;
+  if (m_ui->cbSort->isChecked())                                                            result |= Action::Sort;
+  if (m_ui->cbConstrictExpand->isChecked() && m_ui->rbConstrict->isChecked())               result |= Action::Constrict;
+  if (m_ui->cbConstrictExpand->isChecked() && m_ui->rbExpand->isChecked())                  result |= Action::Expand;
+  if (m_ui->cbSetLanguage->isChecked())                                                     result |= Action::SetLanguage;
+  if (m_ui->cbSetCountry->isChecked())                                                      result |= Action::SetCountry;
+  if (m_ui->cbMultiply->isChecked())                                                        result |= Action::Multiply;
+  if (m_ui->cbSetEndTimestamps->isEnabled() && m_ui->cbSetEndTimestamps->isChecked())       result |= Action::SetEndTimestamps;
+  if (m_ui->cbRemoveEndTimestamps->isEnabled() && m_ui->cbRemoveEndTimestamps->isChecked()) result |= Action::RemoveEndTimestamps;
+  if (m_ui->cbRemoveNames->isChecked())                                                     result |= Action::RemoveNames;
 
   return result;
 }
