@@ -15,14 +15,16 @@ class MassModificationDialog : public QDialog {
   Q_OBJECT;
 public:
   enum Action {
-    Shift            = 0x0001,
-    Sort             = 0x0002,
-    Constrict        = 0x0004,
-    Expand           = 0x0008,
-    SetLanguage      = 0x0010,
-    SetCountry       = 0x0020,
-    Multiply         = 0x0040,
-    SetEndTimestamps = 0x0080,
+    Shift               = 0x0001,
+    Sort                = 0x0002,
+    Constrict           = 0x0004,
+    Expand              = 0x0008,
+    SetLanguage         = 0x0010,
+    SetCountry          = 0x0020,
+    Multiply            = 0x0040,
+    SetEndTimestamps    = 0x0080,
+    RemoveEndTimestamps = 0x0100,
+    RemoveNames         = 0x0200,
   };
   Q_DECLARE_FLAGS(Actions, Action);
 
