@@ -82,6 +82,8 @@ signals:
 public slots:
   virtual void newFile();
   virtual void load();
+  virtual void append(QString const &fileName);
+  virtual void appendSimpleChaptersWithCharacterSet(QString const &characterSet);
   virtual void reloadSimpleChaptersWithCharacterSet(QString const &characterSet);
   virtual void save();
   virtual void saveAsXml();
@@ -96,6 +98,7 @@ public slots:
   virtual void addEditionOrChapterAfter();
   virtual void removeElement();
   virtual void duplicateElement();
+  virtual void copyElementToOtherTab();
   virtual void massModify();
   virtual void generateSubChapters();
   virtual void renumberSubChapters();
@@ -124,12 +127,13 @@ protected:
   void resetData();
   void expandCollapseAll(bool expand, QModelIndex const &parentIdx = {});
 
-  LoadResult loadFromChapterFile();
-  LoadResult loadFromMatroskaFile();
-  LoadResult loadFromMplsFile();
-  LoadResult checkSimpleFormatForBomAndNonAscii(ChaptersPtr const &chapters);
+  LoadResult loadFromChapterFile(QString const &fileName, bool append);
+  LoadResult loadFromMatroskaFile(QString const &fileName, bool append);
+  LoadResult loadFromMplsFile(QString const &fileName, bool append);
+  LoadResult checkSimpleFormatForBomAndNonAscii(ChaptersPtr const &chapters, QString const &fileName, bool append);
+  void reloadOrAppendSimpleChaptersWithCharacterSet(QString const &characterSet, bool append);
 
-  bool readFileEndTimestampForMatroska();
+  bool readFileEndTimestampForMatroska(kax_analyzer_c &analyzer);
 
   void resizeChapterColumnsToContents() const;
   void resizeNameColumnsToContents() const;
@@ -176,8 +180,10 @@ protected:
 
 protected:
   void setupToolTips();
+  void setupCopyToOtherTabMenu();
 
   void chaptersLoaded(ChaptersPtr const &chapters, bool canBeWritten);
+  void appendTheseChapters(ChaptersPtr const &chapters);
 
   QString currentState() const;
   QStringList usedNameLanguages(QStandardItem *parentItem = nullptr);
