@@ -1,5 +1,4 @@
-#ifndef MTX_MKVTOOLNIX_GUI_CHAPTER_EDITOR_TAB_P_H
-#define MTX_MKVTOOLNIX_GUI_CHAPTER_EDITOR_TAB_P_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -20,6 +19,7 @@ class TabPrivate {
 
   QAction *expandAllAction, *collapseAllAction, *addEditionBeforeAction, *addEditionAfterAction, *addChapterBeforeAction, *addChapterAfterAction, *addSubChapterAction, *removeElementAction;
   QAction *duplicateAction, *massModificationAction, *generateSubChaptersAction, *renumberSubChaptersAction;
+  QMenu *copyToOtherTabMenu;
   QList<QWidget *> nameWidgets;
 
   bool ignoreChapterSelectionChanges{};
@@ -32,5 +32,3 @@ class TabPrivate {
 };
 
 }}}
-
-#endif  // MTX_MKVTOOLNIX_GUI_CHAPTER_EDITOR_TAB_P_H
