@@ -33,6 +33,7 @@ public:
   virtual void setupUi() override;
   virtual void setupActions() override;
   virtual std::pair<QString, QString> nextPreviousWindowActionTexts() const override;
+  virtual QVector<Tab *> tabs();
 
 public slots:
   virtual void retranslateUi();
@@ -40,7 +41,7 @@ public slots:
   virtual void tabTitleChanged();
   virtual void enableMenuActions();
   virtual void newFile();
-  virtual void selectFileToOpen();
+  virtual void selectFileToOpen(bool append);
   virtual void save();
   virtual void saveAsXml();
   virtual void saveToMatroska();
@@ -61,7 +62,7 @@ protected:
   virtual Tab *currentTab();
   virtual void forEachTab(std::function<void(Tab &)> const &worker);
 
-  virtual void openFile(QString const &fileName);
+  virtual void openFile(QString const &fileName, bool append);
   virtual void showChapterEditorsWidget();
 
   virtual void dragEnterEvent(QDragEnterEvent *event) override;
