@@ -7,7 +7,7 @@
 #include <matroska/KaxAttached.h>
 
 #include "common/ebml.h"
-#include "common/extern_data.h"
+#include "common/mime.h"
 #include "common/qt.h"
 #include "common/strings/formatting.h"
 #include "mkvtoolnix-gui/forms/header_editor/attached_file_page.h"
@@ -19,10 +19,11 @@
 #include "mkvtoolnix-gui/util/settings.h"
 #include "mkvtoolnix-gui/util/widget.h"
 
-namespace mtx { namespace gui { namespace HeaderEditor {
-
+using namespace libmatroska;
 using namespace mtx::gui;
 
+namespace mtx { namespace gui { namespace HeaderEditor {
+
 AttachedFilePage::AttachedFilePage(Tab &parent,
                                    PageBase &topLevelPage,
                                    KaxAttachedPtr const &attachment)
@@ -55,7 +56,7 @@ AttachedFilePage::retranslateUi() {
 
 void
 AttachedFilePage::init() {
-  for (auto &mimeType : mime_types)
+  for (auto &mimeType : mtx::mime::g_types)
     ui->mimeType->addItem(Q(mimeType.name), Q(mimeType.name));
 
   retranslateUi();
@@ -221,7 +222,7 @@ AttachedFilePage::replaceContent(bool deriveNameAndMimeType) {
   if (!deriveNameAndMimeType)
     return;
 
-  auto mimeType = Q(guess_mime_type(to_utf8(fileName), true));
+  auto mimeType = Q(mtx::mime::guess_type(to_utf8(fileName), true));
 
   ui->name->setText(fileInfo.fileName());
   ui->mimeType->setEditText(mimeType);
