@@ -70,9 +70,15 @@ ValuePage::init() {
   m_cbAddOrRemove = new QCheckBox{this};
 
   if (m_present) {
-    auto semantic = find_ebml_semantic(KaxSegment::ClassInfos, m_callbacks.GlobalId);
-    if (semantic && semantic->Mandatory)
-      m_cbAddOrRemove->setEnabled(false);
+    auto semantic = find_ebml_semantic(libmatroska::KaxSegment::ClassInfos, m_callbacks.GlobalId);
+    if (semantic && semantic->Mandatory) {
+      std::unique_ptr<EbmlElement> elt(&semantic->Create());
+      m_mayBeRemoved = elt->DefaultISset();
+
+    } else if (semantic && !semantic->Mandatory)
+      m_mayBeRemoved = true;
+
+    m_cbAddOrRemove->setEnabled(m_mayBeRemoved);
   }
 
   sizePolicy.setHeightForWidth(m_lStatus->sizePolicy().hasHeightForWidth());
@@ -167,8 +173,7 @@ ValuePage::retranslateUi() {
 
   m_lStatusLabel->setText(QY("Status:"));
   if (m_present) {
-    auto semantic = find_ebml_semantic(KaxSegment::ClassInfos, m_callbacks.GlobalId);
-    if (semantic && semantic->Mandatory)
+    if (!m_mayBeRemoved)
       m_lStatus->setText(Q("%1 %2").arg(QY("This element is currently present in the file.")).arg(QY("It cannot be removed because it is a mandatory header field.")));
     else
       m_lStatus->setText(Q("%1 %2").arg(QY("This element is currently present in the file.")).arg(QY("You can let the header editor remove the element from the file.")));
