@@ -4,8 +4,8 @@
 
 #include <QThread>
 
-#include "common/qt_kax_info.h"
 #include "mkvtoolnix-gui/jobs/job_p.h"
+#include "mkvtoolnix-gui/util/kax_info.h"
 
 namespace mtx { namespace gui { namespace Jobs {
 
@@ -13,7 +13,7 @@ class InfoJobPrivate: public JobPrivate {
 public:
   mtx::gui::Info::InfoConfigPtr config;
   QThread *thread{};
-  mtx::qt_kax_info_c *info{};
+  Util::KaxInfo *info{};
 
 public:
   explicit InfoJobPrivate(Job::Status pStatus, mtx::gui::Info::InfoConfigPtr const &pConfig);
