@@ -85,9 +85,11 @@ public:
 
   virtual void start() = 0;
 
+  virtual QString destinationFileName() const = 0;
   virtual QString displayableType() const = 0;
   virtual QString displayableDescription() const = 0;
   virtual QString outputFolder() const;
+  virtual bool isEditable() const = 0;
 
   void setPendingAuto();
   void setPendingManual();
