@@ -136,7 +136,7 @@ Model::setRowText(QList<QStandardItem *> const &items,
   items.at(StatusColumn)      ->setText(Job::displayableStatus(job.status()));
   items.at(DescriptionColumn) ->setText(job.description());
   items.at(TypeColumn)        ->setText(job.displayableType());
-  items.at(ProgressColumn)    ->setText(to_qs(boost::format("%1%%%") % job.progress()));
+  items.at(ProgressColumn)    ->setText(to_qs(fmt::format("{0}%", job.progress())));
   items.at(DateAddedColumn)   ->setText(Util::displayableDate(job.dateAdded()));
   items.at(DateStartedColumn) ->setText(Util::displayableDate(job.dateStarted()));
   items.at(DateFinishedColumn)->setText(Util::displayableDate(job.dateFinished()));
@@ -272,16 +272,14 @@ Model::onStatusChanged(uint64_t id,
   if (row == RowNotFound)
     return;
 
-  auto &job       = *m_jobsById[id];
-  auto status     = job.status();
-  auto numBefore  = m_toBeProcessed.count();
+  auto &job   = *m_jobsById[id];
+  auto status = job.status();
+
+  // qDebug() << "Model::onStatusChanged id" << id << "old" << static_cast<int>(oldStatus) << "new" << newStatus;
 
   if (job.isToBeProcessed())
     m_toBeProcessed.insert(&job);
 
-  if (m_toBeProcessed.count() != numBefore)
-    updateProgress();
-
   if (included_in(status, Job::PendingManual, Job::PendingAuto, Job::Running))
     job.setDateFinished(QDateTime{});
 
@@ -301,6 +299,8 @@ Model::onStatusChanged(uint64_t id,
   if ((Job::Running == oldStatus) && (Job::Running != newStatus))
     ++m_queueNumDone;
 
+  updateProgress();
+
   if (newStatus != Job::Running)
     job.saveQueueFile();
 
@@ -349,7 +349,7 @@ Model::onProgressChanged(uint64_t id,
 
   auto row = rowFromId(id);
   if (row < rowCount()) {
-    item(row, ProgressColumn)->setText(to_qs(boost::format("%1%%%") % progress));
+    item(row, ProgressColumn)->setText(to_qs(fmt::format("{0}%", progress)));
     updateProgress();
   }
 }
@@ -428,6 +428,7 @@ Model::startJobImmediately(Job &job) {
   MainWindow::watchCurrentJobTab()->disconnectFromJob(job);
   MainWindow::watchJobTool()->viewOutput(job);
 
+  job.setProgress(0);
   job.start();
   updateJobStats();
 }
@@ -479,6 +480,9 @@ Model::updateProgress() {
     } else if (Job::PendingAuto == job->status())
       ++numPendingAuto;
 
+  if ((m_queueNumDone + numRunning + numPendingAuto) == 0)
+    return;
+
   auto progress      = numRunning ? runningProgress / numRunning : 0u;
   auto totalProgress = (m_queueNumDone * 100 + runningProgress) / (m_queueNumDone + numRunning + numPendingAuto);
 
