@@ -1,6 +1,6 @@
 #include "common/common_pch.h"
 
-#include "common/extern_data.h"
+#include "common/mime.h"
 #include "mkvtoolnix-gui/merge/mux_config.h"
 #include "mkvtoolnix-gui/merge/source_file.h"
 #include "mkvtoolnix-gui/merge/attachment.h"
@@ -45,7 +45,7 @@ Attachment::loadSettings(MuxConfig::Loader &l) {
 
 void
 Attachment::guessMIMEType() {
-  m_MIMEType = to_qs(guess_mime_type(to_utf8(m_fileName), true));
+  m_MIMEType = to_qs(mtx::mime::guess_type(to_utf8(m_fileName), true));
 }
 
 void
