@@ -2,7 +2,7 @@
 
 #include <QMenu>
 
-#include "common/extern_data.h"
+#include "common/mime.h"
 #include "common/qt.h"
 #include "common/strings/formatting.h"
 #include "mkvtoolnix-gui/merge/tab.h"
@@ -42,7 +42,7 @@ Tab::setupAttachmentsControls() {
   m_attachmentsMenu->addAction(m_selectAllAttachmentsAction);
 
   // MIME type
-  for (auto &mime_type : mime_types)
+  for (auto &mime_type : mtx::mime::g_types)
     ui->attachmentMIMEType->addItem(to_qs(mime_type.name), to_qs(mime_type.name));
 
   ui->attachmentMIMEType->view()->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
@@ -54,7 +54,7 @@ Tab::setupAttachmentsControls() {
   auto &cfg = Util::Settings::get();
   cfg.handleSplitterSizes(ui->mergeAttachmentsSplitter);
 
-  Util::HeaderViewManager::create(*ui->attachedFiles, "Merge::AttachedFiles");
+  Util::HeaderViewManager::create(*ui->attachedFiles, "Merge::AttachedFiles").setDefaultSizes({ { Q("name"), 180 }, { Q("mimeType"), 180 }, { Q("size"), 100 } });
 
   m_enableSelectedAttachedFilesAction->setIcon(QIcon{Q(":/icons/16x16/checkbox.png")});
   m_disableSelectedAttachedFilesAction->setIcon(QIcon{Q(":/icons/16x16/checkbox-unchecked.png")});
@@ -97,7 +97,7 @@ Tab::setupAttachmentsControls() {
 
   onAttachmentSelectionChanged();
 
-  Util::HeaderViewManager::create(*ui->attachments, "Merge::Attachments");
+  Util::HeaderViewManager::create(*ui->attachments, "Merge::Attachments").setDefaultSizes({ { Q("name"), 180 }, { Q("mimeType"), 180 }, { Q("attachTo"), 130 }, { Q("size"), 100 } });
 }
 
 void
@@ -243,7 +243,6 @@ Tab::addAttachments(QStringList const &fileNames) {
   }
 
   m_attachmentsModel->addAttachments(attachmentsToAdd);
-  resizeAttachmentsColumnsToContents();
 }
 
 void
@@ -288,18 +287,6 @@ Tab::onSelectAllAttachments() {
   ui->attachments->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
 }
 
-void
-Tab::resizeAttachedFilesColumnsToContents()
-  const {
-  Util::resizeViewColumnsToContents(ui->attachedFiles);
-}
-
-void
-Tab::resizeAttachmentsColumnsToContents()
-  const {
-  Util::resizeViewColumnsToContents(ui->attachments);
-}
-
 void
 Tab::onAttachmentSelectionChanged() {
   auto selection = ui->attachments->selectionModel()->selection();
@@ -399,9 +386,6 @@ Tab::retranslateAttachmentsUI() {
   m_attachedFilesModel->retranslateUi();
   m_attachmentsModel->retranslateUi();
 
-  resizeAttachedFilesColumnsToContents();
-  resizeAttachmentsColumnsToContents();
-
   m_enableAllAttachedFilesAction->setText(QY("E&nable all attachments"));
   m_disableAllAttachedFilesAction->setText(QY("Di&sable all attachments"));
 
