@@ -5,14 +5,14 @@
 #include <QString>
 #include <QHash>
 
-#include "mkvtoolnix-gui/merge/track.h"
+#include "mkvtoolnix-gui/merge/enums.h"
 
 namespace mtx { namespace gui { namespace Merge {
 
 struct MkvmergeOptionBuilder {
   QStringList options;
-  QHash<Track::Type, unsigned int> numTracksOfType;
-  QHash<Track::Type, QStringList> enabledTrackIds;
+  QHash<TrackType, unsigned int> numTracksOfType;
+  QHash<TrackType, QStringList> enabledTrackIds;
 
   MkvmergeOptionBuilder() {}
 };
