@@ -711,17 +711,17 @@ void
 MuxConfig::debugDumpFileList()
   const {
   auto num = m_files.count();
-  log_it(boost::format("// Dumping file list with %1% entries\n") % num);
+  log_it(fmt::format("// Dumping file list with {0} entries\n", num));
 
   for (auto idx = 0; idx < num; ++idx) {
     auto const &file = *m_files[idx];
-    log_it(boost::format("%1%/%2% %3%\n") % idx % num % to_utf8(QFileInfo{file.m_fileName}.fileName()));
+    log_it(fmt::format("{0}/{1} {2}\n", idx, num, to_utf8(QFileInfo{file.m_fileName}.fileName())));
 
     for (auto addIdx = 0, addNum = file.m_additionalParts.count(); addIdx < addNum; ++addIdx)
-      log_it(boost::format("  = %1%/%2% %3%\n") % addIdx % addNum % to_utf8(QFileInfo{file.m_additionalParts[addIdx]->m_fileName}.fileName()));
+      log_it(fmt::format("  = {0}/{1} {2}\n", addIdx, addNum, to_utf8(QFileInfo{file.m_additionalParts[addIdx]->m_fileName}.fileName())));
 
     for (auto appIdx = 0, appNum = file.m_appendedFiles.count(); appIdx < appNum; ++appIdx)
-      log_it(boost::format("  + %1%/%2% %3%\n") % appIdx % appNum % to_utf8(QFileInfo{file.m_appendedFiles[appIdx]->m_fileName}.fileName()));
+      log_it(fmt::format("  + {0}/{1} {2}\n", appIdx, appNum, to_utf8(QFileInfo{file.m_appendedFiles[appIdx]->m_fileName}.fileName())));
   }
 }
 
@@ -734,15 +734,15 @@ MuxConfig::debugDumpTrackList()
 void
 MuxConfig::debugDumpSpecificTrackList(QList<Track *> const &tracks) {
   auto num = tracks.count();
-  log_it(boost::format("// Dumping track list with %1% entries\n") % num);
+  log_it(fmt::format("// Dumping track list with {0} entries\n", num));
 
   for (auto idx = 0; idx < num; ++idx) {
     auto const &track = *tracks[idx];
-    log_it(boost::format("%1%/%2% %3% %4% from %5%\n") % idx % num % track.nameForType() % track.m_codec % to_utf8(QFileInfo{track.m_file->m_fileName}.fileName()));
+    log_it(fmt::format("{0}/{1} {2} {3} from {4}\n", idx, num, track.nameForType(), track.m_codec, to_utf8(QFileInfo{track.m_file->m_fileName}.fileName())));
 
     for (auto appIdx = 0, appNum = track.m_appendedTracks.count(); appIdx < appNum; ++appIdx) {
       auto const &appTrack = *track.m_appendedTracks[appIdx];
-      log_it(boost::format("  %1%/%2% %3% %4% from %5%\n") % appIdx % appNum % appTrack.nameForType() % appTrack.m_codec % to_utf8(QFileInfo{appTrack.m_file->m_fileName}.fileName()));
+      log_it(fmt::format("  {0}/{1} {2} {3} from {4}\n", appIdx, appNum, appTrack.nameForType(), appTrack.m_codec, to_utf8(QFileInfo{appTrack.m_file->m_fileName}.fileName())));
     }
   }
 }
