@@ -9,8 +9,6 @@
 
 #include "mkvtoolnix-gui/util/config_file.h"
 
-#define MTXCFG_VERSION 1
-
 class QTemporaryFile;
 
 namespace mtx { namespace gui { namespace Merge {
@@ -75,7 +73,7 @@ public:
 
   QString m_firstInputFileName;
   QString m_title, m_destination, m_destinationAuto, m_globalTags, m_segmentInfo, m_splitOptions;
-  QString m_segmentUIDs, m_previousSegmentUID, m_nextSegmentUID, m_chapters, m_chapterLanguage, m_chapterCharacterSet, m_chapterCueNameFormat, m_additionalOptions;
+  QString m_segmentUIDs, m_previousSegmentUID, m_nextSegmentUID, m_chapters, m_chapterLanguage, m_chapterCharacterSet, m_chapterCueNameFormat, m_chapterDelay, m_chapterStretchBy, m_additionalOptions;
   SplitMode m_splitMode;
   unsigned int m_splitMaxFiles;
   bool m_linkFiles, m_webmMode;
@@ -99,6 +97,9 @@ public:
   QStringList buildMkvmergeOptions() const;
 
   virtual bool hasSourceFileWithTitle() const;
+  virtual bool needChapterNameTemplateAndLanguage() const;
+
+  virtual void verifyStructure() const;
 
   virtual void debugDumpFileList() const;
   virtual void debugDumpTrackList() const;
@@ -108,6 +109,13 @@ protected:
   QStringList buildTrackOrder(QHash<SourceFile *, unsigned int> const &fileNumbers) const;
   QStringList buildAppendToMapping(QHash<SourceFile *, unsigned int> const &fileNumbers) const;
 
+  virtual void fixOlderVersions(Util::ConfigFile &settings);
+  virtual void fixOldVersion1(Util::ConfigFile &settings);
+
+  virtual void setSettingsVersion(Util::ConfigFile &settings, unsigned int version) const;
+
+  virtual QString findErrorInStructure() const;
+
 public:
   static MuxConfigPtr loadSettings(QString const &fileName);
   static void saveProperties(Util::ConfigFile &settings, QVariantMap const &properties);
@@ -115,6 +123,7 @@ public:
   static void debugDumpSpecificTrackList(QList<Track *> const &tracks);
   static QString settingsType();
   static QString determineFirstInputFileName(QList<SourceFilePtr> const &files);
+  static QString formatDelayAndStretchBy(QString const &delay, QString const &stretchBy);
 };
 
 template<typename T>
