@@ -44,13 +44,22 @@ setupLanguageDerivationSubPatterns() {
 
   QStringList codes1List, codes2List, namesList;
 
-  for (auto const &language : g_iso639_languages) {
-    codes1List << Q(language.iso639_1_code);
-    codes2List << Q(language.iso639_2_code);
-    namesList  << QRegularExpression::escape(Q(language.english_name));
+  auto &cfg = Util::Settings::get();
 
+  for (auto const &language : g_iso639_languages) {
+    if (!cfg.m_recognizedTrackLanguagesInFileNames.contains(Q(language.iso639_2_code)))
+      continue;
+
+    if (!language.iso639_1_code.empty())
+      codes1List << Q(language.iso639_1_code);
+
+    if (!language.iso639_2_code.empty())
+      codes2List << Q(language.iso639_2_code);
     if (!language.terminology_abbrev.empty())
       codes2List << Q(language.terminology_abbrev);
+
+    for (auto const &name : Q(language.english_name).split(QRegularExpression{Q(" *; *")}, QString::SkipEmptyParts))
+      namesList  << QRegularExpression::escape(name);
   }
 
   s_iso639_1CodesPattern = codes1List.join(Q("|"));
@@ -96,30 +105,35 @@ SourceFile::operator =(SourceFile const &other) {
   if (this == &other)
     return *this;
 
-  m_properties           = other.m_properties;
-  m_fileName             = other.m_fileName;
-  m_type                 = other.m_type;
-  m_appended             = other.m_appended;
-  m_additionalPart       = other.m_additionalPart;
-  m_isPlaylist           = other.m_isPlaylist;
-  m_playlistDuration     = other.m_playlistDuration;
-  m_playlistSize         = other.m_playlistSize;
-  m_playlistChapters     = other.m_playlistChapters;
-  m_playlistFiles        = other.m_playlistFiles;
-  m_appendedTo           = other.m_appendedTo;
-  m_probeRangePercentage = other.m_probeRangePercentage;
+  m_properties                = other.m_properties;
+  m_programMap                = other.m_programMap;
+  m_fileName                  = other.m_fileName;
+  m_type                      = other.m_type;
+  m_playlistFiles             = other.m_playlistFiles;
+  m_appended                  = other.m_appended;
+  m_additionalPart            = other.m_additionalPart;
+  m_isPlaylist                = other.m_isPlaylist;
+  m_dontScanForOtherPlaylists = other.m_dontScanForOtherPlaylists;
+  m_appendedTo                = other.m_appendedTo;
+  m_playlistDuration          = other.m_playlistDuration;
+  m_playlistSize              = other.m_playlistSize;
+  m_playlistChapters          = other.m_playlistChapters;
+  m_probeRangePercentage      = other.m_probeRangePercentage;
 
   m_tracks.clear();
   m_attachedFiles.clear();
   m_additionalParts.clear();
   m_appendedFiles.clear();
-  m_playlistFiles.clear();
 
-  for (auto const &track : other.m_tracks)
+  for (auto const &track : other.m_tracks) {
     m_tracks << std::make_shared<Track>(*track);
+    m_tracks.back()->m_file = this;
+  }
 
-  for (auto const &attachedFile : other.m_attachedFiles)
+  for (auto const &attachedFile : other.m_attachedFiles) {
     m_attachedFiles << std::make_shared<Track>(*attachedFile);
+    m_attachedFiles.back()->m_file = this;
+  }
 
   for (auto const &file : other.m_additionalParts)
     m_additionalParts << std::make_shared<SourceFile>(*file);
@@ -291,7 +305,7 @@ SourceFile::fixAssociations(MuxConfig::Loader &l) {
 }
 
 Track *
-SourceFile::findNthOrLastTrackOfType(Track::Type type,
+SourceFile::findNthOrLastTrackOfType(TrackType type,
                                      int nth)
   const {
   auto nthFound   = -1;
@@ -322,7 +336,7 @@ SourceFile::buildMkvmergeOptions(QStringList &options)
   for (auto const &attachedFile : m_attachedFiles)
     attachedFile->buildMkvmergeOptions(opt);
 
-  auto buildTrackIdArg = [&options,&opt](Track::Type type, QString const &enabled, QString const &disabled) {
+  auto buildTrackIdArg = [&options,&opt](TrackType type, QString const &enabled, QString const &disabled) {
     if (!enabled.isEmpty() && !opt.enabledTrackIds[type].isEmpty() && (static_cast<unsigned int>(opt.enabledTrackIds[type].size()) < opt.numTracksOfType[type]))
       options << enabled << opt.enabledTrackIds[type].join(Q(","));
 
@@ -330,14 +344,14 @@ SourceFile::buildMkvmergeOptions(QStringList &options)
       options << disabled;
   };
 
-  buildTrackIdArg(Track::Audio,      Q("--audio-tracks"),    Q("--no-audio"));
-  buildTrackIdArg(Track::Video,      Q("--video-tracks"),    Q("--no-video"));
-  buildTrackIdArg(Track::Subtitles,  Q("--subtitle-tracks"), Q("--no-subtitles"));
-  buildTrackIdArg(Track::Buttons,    Q("--button-tracks"),   Q("--no-buttons"));
-  buildTrackIdArg(Track::Attachment, Q("--attachments"),     Q("--no-attachments"));
-  buildTrackIdArg(Track::Tags,       Q("--track-tags"),      Q("--no-track-tags"));
-  buildTrackIdArg(Track::GlobalTags, Q(""),                  Q("--no-global-tags"));
-  buildTrackIdArg(Track::Chapters,   Q(""),                  Q("--no-chapters"));
+  buildTrackIdArg(TrackType::Audio,      Q("--audio-tracks"),    Q("--no-audio"));
+  buildTrackIdArg(TrackType::Video,      Q("--video-tracks"),    Q("--no-video"));
+  buildTrackIdArg(TrackType::Subtitles,  Q("--subtitle-tracks"), Q("--no-subtitles"));
+  buildTrackIdArg(TrackType::Buttons,    Q("--button-tracks"),   Q("--no-buttons"));
+  buildTrackIdArg(TrackType::Attachment, Q("--attachments"),     Q("--no-attachments"));
+  buildTrackIdArg(TrackType::Tags,       Q("--track-tags"),      Q("--no-track-tags"));
+  buildTrackIdArg(TrackType::GlobalTags, Q(""),                  Q("--no-global-tags"));
+  buildTrackIdArg(TrackType::Chapters,   Q(""),                  Q("--no-chapters"));
 
   options += opt.options;
   if (m_appendedTo)
@@ -358,6 +372,9 @@ SourceFile::setDefaults() {
   for (auto const &track : m_tracks)
     track->setDefaults(languageDerivedFromFileName);
 
+  for (auto const &attachedFile : m_attachedFiles)
+    attachedFile->setDefaults(languageDerivedFromFileName);
+
   for (auto const &appendedFile : m_appendedFiles)
     appendedFile->setDefaults();
 }
@@ -376,28 +393,37 @@ SourceFile::setupProgramMapFromProperties() {
   }
 }
 
+QString
+SourceFile::defaultRegexForDerivingLanguageFromFileName() {
+  return Q("[[({.+=#-](<ISO_639_1_CODES>|<ISO_639_2_CODES>|<LANGUAGE_NAMES>)[])}.+=#-]");
+}
+
 QRegularExpression
 SourceFile::regexForDerivingLanguageFromFileName() {
-  static boost::optional<QRegularExpression> s_regex;
-
   setupLanguageDerivationSubPatterns();
 
-  auto &cfg = Util::Settings::get();
-  if (!cfg.m_regexForDerivingTrackLanguagesFromFileNames.isEmpty())
-    return QRegularExpression(replaceLanguageSubPatterns(cfg.m_regexForDerivingTrackLanguagesFromFileNames), QRegularExpression::CaseInsensitiveOption);
+  auto &cfg    = Util::Settings::get();
+  auto pattern = !cfg.m_regexForDerivingTrackLanguagesFromFileNames.isEmpty() ? cfg.m_regexForDerivingTrackLanguagesFromFileNames : defaultRegexForDerivingLanguageFromFileName();
 
-  if (s_regex)
-    return *s_regex;
-
-  auto pattern = replaceLanguageSubPatterns(Q("[[({.+=#-](<ISO_639_1_CODES>|<ISO_639_2_CODES>|<LANGUAGE_NAMES>)[])}.+=#-]"));
-  s_regex      = QRegularExpression{pattern, QRegularExpression::CaseInsensitiveOption};
-
-  return *s_regex;
+  return QRegularExpression{replaceLanguageSubPatterns(pattern), QRegularExpression::CaseInsensitiveOption};
 }
 
 QString
 SourceFile::deriveLanguageFromFileName() {
-  auto matches = regexForDerivingLanguageFromFileName().match(QFileInfo{m_fileName}.fileName());
+  auto fileName = QFileInfo{m_fileName}.fileName();
+  auto matches  = QRegularExpression{Q("s\\d+e\\d{2,}(.+)"), QRegularExpression::CaseInsensitiveOption}.match(fileName);
+
+  if (matches.hasMatch()) {
+    fileName = matches.captured(1);
+    qDebug() << "found season/episode code; only using postfix:" << fileName;
+  }
+
+  auto regex = regexForDerivingLanguageFromFileName();
+  if (!regex.isValid()) {
+    qDebug() << "regex for deriving language from file name is invalid:" << regex;
+  }
+
+  matches = regex.match(fileName);
 
   if (!matches.hasMatch()) {
     qDebug() << "language could not be derived: no match found";
@@ -429,4 +455,11 @@ SourceFile::deriveLanguageFromFileName() {
   return {};
 }
 
+void
+SourceFile::setupFromPreferences() {
+  s_iso639_1CodesPattern.clear();
+  s_iso639_2CodesPattern.clear();
+  s_languageNamesPattern.clear();
+}
+
 }}}
