@@ -6,6 +6,7 @@
 #include <QVariant>
 
 #include "common/qt.h"
+#include "mkvtoolnix-gui/merge/enums.h"
 #include "mkvtoolnix-gui/merge/mux_config.h"
 
 namespace mtx { namespace gui { namespace Merge {
@@ -18,51 +19,30 @@ using TrackPtr = std::shared_ptr<Track>;
 
 class Track {
 public:
-  enum Type {
-    Audio = 0,
-    Video,
-    Subtitles,
-    Buttons,
-    Chapters,
-    GlobalTags,
-    Tags,
-    Attachment,
-    TypeMin = Audio,
-    TypeMax = Attachment
-  };
-
-  enum Compression {
-    CompDefault = 0,
-    CompNone,
-    CompZlib,
-    CompMin = CompDefault,
-    CompMax = CompZlib
-  };
-
   QVariantMap m_properties;
 
   SourceFile *m_file{};
   Track *m_appendedTo{};
   QList<Track *> m_appendedTracks;
 
-  Type m_type{Audio};
+  TrackType m_type{TrackType::Audio};
   int64_t m_id{-1};
 
   bool m_muxThis{true}, m_setAspectRatio{true}, m_defaultTrackFlagWasSet{}, m_defaultTrackFlagWasPresent{}, m_forcedTrackFlagWasSet{}, m_aacSbrWasDetected{}, m_nameWasPresent{}, m_fixBitstreamTimingInfo{}, m_reduceAudioToCore{};
   bool m_removeDialogNormalizationGain{};
   QString m_name, m_codec, m_language, m_tags, m_delay, m_stretchBy, m_defaultDuration, m_timestamps, m_aspectRatio, m_displayWidth, m_displayHeight, m_cropping, m_characterSet, m_additionalOptions;
   unsigned int m_defaultTrackFlag{}, m_forcedTrackFlag{}, m_stereoscopy{}, m_naluSizeLength{}, m_cues{}, m_aacIsSBR{};
-  Compression m_compression{CompDefault};
+  TrackCompression m_compression{TrackCompression::Default};
   boost::optional<bool> m_effectiveDefaultTrackFlag;
 
   int64_t m_size{};
   QString m_attachmentDescription;
 
 public:
-  explicit Track(SourceFile *file = nullptr, Type = Audio);
+  explicit Track(SourceFile *file = nullptr, TrackType = TrackType::Audio);
   virtual ~Track();
 
-  virtual bool isType(Type type) const;
+  virtual bool isType(TrackType type) const;
   virtual bool isAudio() const;
   virtual bool isVideo() const;
   virtual bool isSubtitles() const;
@@ -81,6 +61,7 @@ public:
   virtual bool canSetAacToSbr() const;
 
   virtual void setDefaults(QString const &languageDerivedFromFileName);
+  virtual void setDefaultsNonRegular();
   virtual QString extractAudioDelayFromFileName() const;
 
   virtual void saveSettings(Util::ConfigFile &settings) const;
@@ -92,6 +73,9 @@ public:
   virtual std::string debugInfo() const;
 
   void buildMkvmergeOptions(MkvmergeOptionBuilder &opt) const;
+
+public:
+  static QString nameForType(TrackType type);
 };
 
 }}}
