@@ -1,5 +1,4 @@
-#ifndef MTX_MKVTOOLNIX_GUI_UTIL_CACHE_H
-#define MTX_MKVTOOLNIX_GUI_UTIL_CACHE_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -34,5 +33,3 @@ private:
 };
 
 }}}
-
-#endif // MTX_MKVTOOLNIX_GUI_UTIL_CACHE_H
