@@ -106,11 +106,8 @@ FancyTabBar::tabSizeHint(bool minimum)
   int spacing       = 8;
   int width         = 60 + spacing + 2;
   int maxLabelwidth = 0;
-  for (int tab=0 ; tab<count() ;++tab) {
-    int width = fm.width(tabText(tab));
-    if (width > maxLabelwidth)
-      maxLabelwidth = width;
-  }
+  for (int tab=0 ; tab<count() ;++tab)
+    maxLabelwidth = std::max(maxLabelwidth, fm.width(tabText(tab)));
   int iconHeight = minimum ? 0 : 32;
   return QSize(qMax(width, maxLabelwidth + 4), iconHeight + spacing + fm.height());
 }
