@@ -4,6 +4,8 @@
 
 #include <QObject>
 
+#include "common/qt.h"
+
 class QString;
 class QTreeView;
 
@@ -13,12 +15,21 @@ class HeaderViewManagerPrivate;
 class HeaderViewManager : public QObject {
   Q_OBJECT;
 
+protected:
+  MTX_DECLARE_PRIVATE(HeaderViewManagerPrivate);
+
+  std::unique_ptr<HeaderViewManagerPrivate> const p_ptr;
+
+  explicit HeaderViewManager(HeaderViewManagerPrivate &p);
+
 public:
   explicit HeaderViewManager(QObject *parent = nullptr);
   virtual ~HeaderViewManager();
 
   void manage(QTreeView &treeView, QString const &name);
 
+  HeaderViewManager &setDefaultSizes(QHash<QString, int> const &defaultSizes);
+
 public slots:
   void saveState();
   void restoreState();
@@ -28,17 +39,13 @@ public slots:
   void resetColumns();
 
 public:
-  static HeaderViewManager *create(QTreeView &treeView, QString const &name);
+  static HeaderViewManager &create(QTreeView &treeView, QString const &name);
 
 protected:
   void restoreHidden(QStringList const &hiddenColumns);
   void restoreVisualIndexes(QStringList const &columnOrder);
   void restoreSizes(QStringList const &columnSizes);
   QString symbolicColumnName(int logicalIndex);
-
-  Q_DECLARE_PRIVATE(HeaderViewManager);
-
-  QScopedPointer<HeaderViewManagerPrivate> const d_ptr;
 };
 
 }}}
