@@ -14,12 +14,16 @@ namespace Ui {
 class SideBySideMultiSelect;
 }
 
+class SideBySideMultiSelectPrivate;
 class SideBySideMultiSelect : public QWidget {
   Q_OBJECT;
 
 protected:
-  // UI stuff:
-  std::unique_ptr<Ui::SideBySideMultiSelect> ui;
+  MTX_DECLARE_PRIVATE(SideBySideMultiSelectPrivate);
+
+  std::unique_ptr<SideBySideMultiSelectPrivate> const p_ptr;
+
+  explicit SideBySideMultiSelect(SideBySideMultiSelectPrivate &p);
 
 public:
   using Item     = std::pair<QString, QString>;
@@ -30,7 +34,7 @@ public:
   ~SideBySideMultiSelect();
 
   void retranslateUi();
-  void setToolTips(QString const &available, QString const &selected);
+  void setToolTips(QString const &available, QString const &selected = {});
   void setItems(ItemList const &all, QStringList const &selected);
   void setItems(QStringList const &all, QStringList const &selected);
 
@@ -46,6 +50,7 @@ public slots:
 
   void moveToAvailable();
   void moveToSelected();
+  void revertLists();
 
 protected:
   void setupConnections();
