@@ -21,6 +21,7 @@
 #include "mkvtoolnix-gui/util/file_dialog.h"
 #include "mkvtoolnix-gui/util/message_box.h"
 #include "mkvtoolnix-gui/util/settings.h"
+#include "mkvtoolnix-gui/util/settings_names.h"
 #include "mkvtoolnix-gui/util/widget.h"
 
 namespace mtx { namespace gui { namespace Util {
@@ -104,14 +105,14 @@ setToolTip(QWidget *widget,
   // automatically if the format is recognized to be Rich Text. See
   // http://doc.qt.io/qt-5/qstandarditem.html
 
-  widget->setToolTip(toolTip.startsWith('<') ? toolTip : Q("<span>%1</span>").arg(toolTip.toHtmlEscaped()));
+  widget->setToolTip(toolTip.isEmpty() || toolTip.startsWith('<') ? toolTip : Q("<span>%1</span>").arg(toolTip.toHtmlEscaped()));
 }
 
 void
 saveWidgetGeometry(QWidget *widget) {
   auto reg = Util::Settings::registry();
 
-  reg->beginGroup("windowGeometry");
+  reg->beginGroup(s_grpWindowGeometry);
   reg->setValue(widget->objectName(), widget->saveGeometry());
   reg->endGroup();
 }
@@ -120,7 +121,7 @@ void
 restoreWidgetGeometry(QWidget *widget) {
   auto reg = Util::Settings::registry();
 
-  reg->beginGroup("windowGeometry");
+  reg->beginGroup(s_grpWindowGeometry);
   widget->restoreGeometry(reg->value(widget->objectName()).toByteArray());
   reg->endGroup();
 }
@@ -185,7 +186,7 @@ addSegmentUIDFromFileToLineEdit(QWidget &parent,
     auto uidString  = QString{};
     auto src        = segmentUID->data();
 
-    for (unsigned int idx = 0u, numBytes = segmentUID->byte_size(); idx < numBytes; ++idx)
+    for (int idx = 0, numBytes = segmentUID->byte_size(); idx < numBytes; ++idx)
       uidString += Q("%1").arg(QString::number(src[idx], 16), 2, '0').toUpper();
 
     if (!append || lineEdit.text().isEmpty())
