@@ -11,8 +11,7 @@
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef MTX_P_DIRAC_H
-#define MTX_P_DIRAC_H
+#pragma once
 
 #include "common/common_pch.h"
 
@@ -26,7 +25,7 @@ protected:
   dirac::sequence_header_t m_seqhdr;
   bool m_headers_found;
 
-  int64_t m_previous_timecode;
+  int64_t m_previous_timestamp;
 
 public:
   dirac_video_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti);
@@ -45,5 +44,3 @@ protected:
   virtual void flush_frames();
   virtual void headers_found();
 };
-
-#endif // MTX_P_DIRAC_H
