@@ -57,8 +57,8 @@ mp3_packetizer_c::handle_garbage(int64_t bytes) {
 
     if (0 < offset) {
       mxinfo_tid(m_ti.m_fname, m_ti.m_id,
-                 boost::format(Y("This MPEG audio track contains %1% bytes of non-MP3 data at the beginning. "
-                                 "This corresponds to a delay of %2%ms. This delay will be used instead of the garbage data.\n")) % bytes % (offset / 1000000));
+                 fmt::format(Y("This MPEG audio track contains {0} bytes of non-MP3 data at the beginning. "
+                               "This corresponds to a delay of {1}ms. This delay will be used instead of the garbage data.\n"), bytes, offset / 1000000));
       warning_printed             = true;
       m_ti.m_tcsync.displacement += offset;
     }
@@ -67,10 +67,11 @@ mp3_packetizer_c::handle_garbage(int64_t bytes) {
   if (!warning_printed)
     m_packet_extensions.push_back(std::make_shared<before_adding_to_cluster_cb_packet_extension_c>([this, bytes](packet_cptr const &packet, int64_t timestamp_offset) {
       mxwarn_tid(m_ti.m_fname, m_ti.m_id,
-                 boost::format("%1% %2%\n")
-                 % (boost::format(NY("This audio track contains %1% byte of invalid data which was skipped before timestamp %2%.",
-                                     "This audio track contains %1% bytes of invalid data which were skipped before timestamp %2%.", bytes)) % bytes % format_timestamp(packet->assigned_timestamp - timestamp_offset))
-                 % Y("The audio/video synchronization may have been lost."));
+                 fmt::format("{0} {1}\n",
+                             fmt::format(NY("This audio track contains {0} byte of invalid data which was skipped before timestamp {1}.",
+                                            "This audio track contains {0} bytes of invalid data which were skipped before timestamp {1}.", bytes),
+                                         bytes, format_timestamp(packet->assigned_timestamp - timestamp_offset)),
+                             Y("The audio/video synchronization may have been lost.")));
     }));
 }
 
@@ -96,7 +97,7 @@ mp3_packetizer_c::get_mp3_packet(mp3_header_t *mp3header) {
     if (!mp3header->is_tag)
       break;
 
-    mxverb(2, boost::format("mp3_packetizer: Removing TAG packet with size %1%\n") % mp3header->framesize);
+    mxverb(2, fmt::format("mp3_packetizer: Removing TAG packet with size {0}\n", mp3header->framesize));
     m_byte_buffer.remove(mp3header->framesize + pos);
   }
 
