@@ -2,7 +2,7 @@
    mkvmerge -- utility for splicing together matroska files
    from component media subtypes
 
-   Distributed under the GPL
+   Distributed under the GPL v2
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
@@ -13,6 +13,8 @@
 
 #include "common/common_pch.h"
 
+#include <matroska/KaxTracks.h>
+
 #include "common/codec.h"
 #include "merge/connection_checks.h"
 #include "output/p_realaudio.h"
@@ -39,8 +41,8 @@ ra_packetizer_c::~ra_packetizer_c() {
 
 void
 ra_packetizer_c::set_headers() {
-  std::string codec_id = (boost::format("A_REAL/%1%%2%%3%%4%")
-                          % (char)(m_fourcc >> 24) % (char)((m_fourcc >> 16) & 0xff) % (char)((m_fourcc >> 8) & 0xff) % (char)(m_fourcc & 0xff)).str();
+  std::string codec_id = fmt::format("A_REAL/{0}{1}{2}{3}",
+                                      char(m_fourcc >> 24), char((m_fourcc >> 16) & 0xff), char((m_fourcc >> 8) & 0xff), char(m_fourcc & 0xff));
   set_codec_id(balg::to_upper_copy(codec_id));
   set_audio_sampling_freq((float)m_samples_per_sec);
   set_audio_channels(m_channels);
