@@ -25,11 +25,12 @@ using namespace libmatroska;
 
 truehd_packetizer_c::truehd_packetizer_c(generic_reader_c *p_reader,
                                          track_info_c &p_ti,
-                                         truehd_frame_t::codec_e codec,
+                                         mtx::truehd::frame_t::codec_e codec,
                                          int sampling_rate,
                                          int channels)
   : generic_packetizer_c{p_reader, p_ti}
   , m_first_frame{true}
+  , m_remove_dialog_normalization_gain{get_option_for_track(m_ti.m_remove_dialog_normalization_gain, m_ti.m_id)}
   , m_current_samples_per_frame{}
   , m_ref_timestamp{}
   , m_timestamp_calculator{sampling_rate}
@@ -54,8 +55,8 @@ truehd_packetizer_c::set_headers() {
 }
 
 void
-truehd_packetizer_c::process_framed(truehd_frame_cptr const &frame,
-                                    int64_t provided_timestamp) {
+truehd_packetizer_c::process_framed(mtx::truehd::frame_cptr const &frame,
+                                    boost::optional<int64_t> provided_timestamp) {
   m_timestamp_calculator.add_timestamp(provided_timestamp);
 
   if (frame->is_ac3())
@@ -66,11 +67,16 @@ truehd_packetizer_c::process_framed(truehd_frame_cptr const &frame,
     m_current_samples_per_frame = frame->m_samples_per_frame;
   }
 
-  auto samples   = 0 == frame->m_samples_per_frame ? m_current_samples_per_frame : frame->m_samples_per_frame;
-  auto timestamp = m_timestamp_calculator.get_next_timestamp(samples).to_ns();
-  auto duration  = m_timestamp_calculator.get_duration(samples).to_ns();
+  auto samples            = 0 == frame->m_samples_per_frame ? m_current_samples_per_frame : frame->m_samples_per_frame;
+  auto timestamp          = m_timestamp_calculator.get_next_timestamp(samples).to_ns();
+  auto duration           = m_timestamp_calculator.get_duration(samples).to_ns();
+  auto packet             = std::make_shared<packet_t>(frame->m_data, timestamp, duration, frame->is_sync() ? -1 : m_ref_timestamp);
+  packet->discard_padding = m_discard_padding.get_next().get_value_or({});
 
-  add_packet(std::make_shared<packet_t>(frame->m_data, timestamp, duration, frame->is_sync() ? -1 : m_ref_timestamp));
+  if (frame->is_sync() && frame->is_truehd() && m_remove_dialog_normalization_gain)
+    mtx::truehd::remove_dialog_normalization_gain(frame->m_data->get_buffer(), frame->m_data->get_size());
+
+  add_packet(packet);
 
   m_ref_timestamp = timestamp;
 }
@@ -78,6 +84,7 @@ truehd_packetizer_c::process_framed(truehd_frame_cptr const &frame,
 int
 truehd_packetizer_c::process(packet_cptr packet) {
   m_timestamp_calculator.add_timestamp(packet);
+  m_discard_padding.add_maybe(packet->discard_padding);
 
   m_parser.add_data(packet->data->get_buffer(), packet->data->get_size());
 
@@ -89,11 +96,11 @@ truehd_packetizer_c::process(packet_cptr packet) {
 void
 truehd_packetizer_c::flush_frames() {
   while (m_parser.frame_available())
-    process_framed(m_parser.get_next_frame(), -1);
+    process_framed(m_parser.get_next_frame());
 }
 
 void
-truehd_packetizer_c::adjust_header_values(truehd_frame_cptr const &frame) {
+truehd_packetizer_c::adjust_header_values(mtx::truehd::frame_cptr const &frame) {
   if (!m_first_frame)
     return;
 
@@ -134,7 +141,7 @@ truehd_packetizer_c::flush_impl() {
 
 connection_result_e
 truehd_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                 std::string &error_message) {
+                                    std::string &error_message) {
   truehd_packetizer_c *asrc = dynamic_cast<truehd_packetizer_c *>(src);
   if (!asrc)
     return CAN_CONNECT_NO_FORMAT;
