@@ -119,7 +119,7 @@ parse_args(std::vector<std::string> &args) {
       } else {
         uint32_t id = element_name_to_id(*arg);
         if (0 == id)
-          mxerror(boost::format(Y("Unknown element name in '--master %1%'\n")) % *arg);
+          mxerror(fmt::format(Y("Unknown element name in '--master {0}'\n"), *arg));
         g_is_master[id] = true;
       }
 
@@ -282,11 +282,11 @@ parse_content(int level,
       if (element_name.empty())
         element_name      = Y("unknown");
 
-      mxinfo(boost::format(Y("%1%pos %2% id 0x%|3$x| size %4% header size %5% (%6%)\n"))
-             % level_string(level) % element_start_pos % id.value % size.value % (id.coded_size + size.coded_size) % element_name);
+      mxinfo(fmt::format(Y("{0}pos {1} id 0x{2:x} size {3} header size {4} ({5})\n"),
+                         level_string(level), element_start_pos, id.value, size.value, id.coded_size + size.coded_size, element_name));
 
       if (size.is_unknown()) {
-        mxinfo(boost::format(Y("%1%  Warning: size is coded as 'unknown' (all bits are set)\n")) % level_string(level));
+        mxinfo(fmt::format(Y("{0}  Warning: size is coded as 'unknown' (all bits are set)\n"), level_string(level)));
 
         // In Matroska segments often have an unknown size – so don't
         // warn about it.
@@ -297,10 +297,10 @@ parse_content(int level,
       int64_t content_end_pos = size.is_unknown() ? end_pos : g_in->getFilePointer() + size.value;
 
       if (content_end_pos > end_pos) {
-        mxinfo(boost::format(Y("%1%  Error: Element ends after scope\n")) % level_string(level));
+        mxinfo(fmt::format(Y("{0}  Error: Element ends after scope\n"), level_string(level)));
         g_errors_found = true;
         if (!g_in->setFilePointer2(end_pos))
-          mxerror(boost::format(Y("Error: Seek to %1%\n")) % end_pos);
+          mxerror(fmt::format(Y("Error: Seek to {0}\n"), end_pos));
         return;
       }
 
@@ -308,7 +308,7 @@ parse_content(int level,
         parse_content(level + 1, content_end_pos);
 
       if (!g_in->setFilePointer2(content_end_pos))
-        mxerror(boost::format(Y("Error: Seek to %1%\n")) % content_end_pos);
+        mxerror(fmt::format(Y("Error: Seek to {0}\n"), content_end_pos));
 
     } catch (id_error_c &error) {
       std::string message
@@ -318,11 +318,11 @@ parse_content(int level,
         : id_error_c::longer_than_four_bytes == error.code ? Y("ID is longer than four bytes")
         :                                                    Y("reason is unknown");
 
-      mxinfo(boost::format(Y("%1%Error at %2%: error reading the element ID (%3%)\n")) % level_string(level) % element_start_pos % message);
+      mxinfo(fmt::format(Y("{0}Error at {1}: error reading the element ID ({2})\n"), level_string(level), element_start_pos, message));
       g_errors_found = true;
 
       if (!g_in->setFilePointer2(end_pos))
-        mxerror(boost::format(Y("Error: Seek to %1%\n")) % end_pos);
+        mxerror(fmt::format(Y("Error: Seek to {0}\n"), end_pos));
       return;
 
     } catch (size_error_c &error) {
@@ -331,11 +331,11 @@ parse_content(int level,
         : size_error_c::end_of_scope == error.code ? Y("End of scope")
         :                                            Y("reason is unknown");
 
-      mxinfo(boost::format(Y("%1%Error at %2%: error reading the element size (%3%)\n")) % level_string(level) % element_start_pos % message);
+      mxinfo(fmt::format(Y("{0}Error at {1}: error reading the element size ({2})\n"), level_string(level), element_start_pos, message));
       g_errors_found = true;
 
       if (!g_in->setFilePointer2(end_pos))
-        mxerror(boost::format(Y("Error: Seek to %1%\n")) % end_pos);
+        mxerror(fmt::format(Y("Error: Seek to {0}\n"), end_pos));
       return;
 
     } catch (...) {
@@ -355,7 +355,7 @@ parse_file(const std::string &file_name) {
   g_end       = std::min(g_file_size, g_end);
 
   if (!in.setFilePointer2(g_start))
-    mxerror(boost::format(Y("Error: Seek to %1%\n")) % g_start);
+    mxerror(fmt::format(Y("Error: Seek to {0}\n"), g_start));
 
   parse_content(0, g_end);
 
