@@ -71,4 +71,31 @@ TEST(ListUtils, none_of) {
   EXPECT_FALSE(mtx::none_of<int>([](int val) { return val < 56; }, 54, 48, 42));
 }
 
+TEST(ListUtils, any) {
+  std::vector<int> vals{2, 4, 6, 8, 10};
+
+  EXPECT_TRUE(mtx::any(vals, [](int i) { return i == 4; }));
+  EXPECT_FALSE(mtx::any(vals, [](int i) { return (i % 2) == 1; }));
+
+  EXPECT_FALSE(mtx::any(std::vector<int>{}, [](int i) { return i != 0; }));
+}
+
+TEST(ListUtils, none) {
+  std::vector<int> vals{2, 4, 6, 8, 10};
+
+  EXPECT_TRUE(mtx::none(vals, [](int i) { return (i % 2) == 1; }));
+  EXPECT_FALSE(mtx::none(vals, [](int i) { return i == 4; }));
+
+  EXPECT_TRUE(mtx::none(std::vector<int>{}, [](int i) { return i != 0; }));
+}
+
+TEST(ListUtils, all) {
+  std::vector<int> vals{2, 4, 6, 8, 10};
+
+  EXPECT_TRUE(mtx::all(vals, [](int i) { return (i % 2) == 0; }));
+  EXPECT_FALSE(mtx::all(vals, [](int i) { return i > 7; }));
+
+  EXPECT_TRUE(mtx::none(std::vector<int>{}, [](int i) { return i != 0; }));
+}
+
 }
